# Generated by Django 1.9.7 on 2016-07-13 03:49
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('feedback', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='questionmessage',
            name='answer',
            field=models.TextField(blank=True, null=True, verbose_name='Answer'),
        ),
        migrations.AddField(
            model_name='questionmessage',
            name='is_visible',
            field=models.BooleanField(default=False, verbose_name='Is Visible'),
        ),
    ]
