{% extends "dartcms/views/grid.html" %}

{% load i18n %}

{% block breadcrumbs_current_path %}
    {{ block.super }}
    <li class="active">{% trans 'Change Password' %}</li>
{% endblock %}

{% block page_content %}
    <div class="page-header">
        <h1>{{ page_header|capfirst }}
            <small>{% trans 'Change Password' %}</small>
        </h1>
    </div>
    <div class="well">
        <form method="POST" class="form-horizontal" enctype="multipart/form-data">
            {% csrf_token %}
            {% include "dartcms/forms/horizontal.html" %}
            <div class="form-group">
                <div class="col-xs-9 col-xs-offset-3">
                    {% block form_actions %}
                        <button type="submit" class="btn btn-primary">{% trans 'Accept Changes' %}</button>
                        <a href="{{ index_url }}" class="btn btn-link">{% trans 'Cancel' %}</a>
                    {% endblock %}
                </div>
            </div>
        </form>
    </div>
{% endblock %}