.datebox-calendar-inner {
  height: 180px;
}
.datebox-button {
  padding: 0 5px;
  text-align: center;
}
.datebox-button a {
  line-height: 22px;
  font-size: 12px;
  font-weight: bold;
  text-decoration: none;
  opacity: 0.6;
  filter: alpha(opacity=60);
}
.datebox-button a:hover {
  opacity: 1.0;
  filter: alpha(opacity=100);
}
.datebox-current,
.datebox-close {
  float: left;
}
.datebox-close {
  float: right;
}
.datebox .combo-arrow {
  background-image: url('images/datebox_arrow.png');
  background-position: center center;
}
.datebox-button {
  background-color: #555;
}
.datebox-button a {
  color: #fff;
}
