.form-window {
  width: 350px;
  margin: 100px auto;
}

.input-group-addon {
  i {
    &.fa {
      width: 12px;
    }
  }
}

.error {
  display: block;
  margin: 5px 0 15px 0;
  padding: 8px;
  background-color: #f2dede;
  border-color: #eed3d7;
  color: #b94a48;
  list-style: none;
  .border-radius(4px);
}

.errorlist {
  margin: 5px 0 15px 0;
  padding: 8px;
  background-color: #f2dede;
  border-color: #eed3d7;
  color: #b94a48;
  list-style: none;
  .border-radius(4px);

  li {
    margin-bottom: 5px;

    &:last-child {
      margin-bottom: 0;
    }
  }
}

.form-inline {
  .form-group {
    margin-right: 10px;
    position: relative;
    top: 3px;

    label {
      margin-right: 10px;
    }

    .datetime {
      width: 150px;
    }

    .date, .time {
      width: 100px;
    }
  }

  .checkbox {
    position: relative;
    top: -4px;
  }
}

.empty-formset-form {
  display: none;
}

.form-modal {
  left: 260px;
  margin-left: -260px;
  overflow: visible;

  a.close-modal {
    top: 6px;
    right: 6px;
  }
}

.multiselect-container {
  li {
    a {
      label {
        padding: 3px 20px !important;

        input {
          width: 0 !important;
          height: 0 !important;
        }
      }
    }
  }
}

.search-form-wrapper {
  form {
    .form-control {
      max-width: 200px;
      margin-bottom: 5px;
    }
  }
}

.inlines-wrapper {
  &>.form-group {
    margin-bottom: 40px;
    padding-bottom: 20px;
  }

  .inlines {
    margin-bottom: 20px;
    & > fieldset {
      position: relative;
      border-radius: 5px;
      padding: 20px;
      &:nth-child(odd) {
        background: #EEE;
      }
      .close-formset {
        position: absolute;
        top: 5px;
        right: 5px;
        font-size: 30px;
        line-height: 30px;
        &:hover, &:focus, &:active {
          text-decoration: none;
        }
      }
    }
  }
}