# Generated by Django 1.10.4 on 2016-12-14 05:12
from __future__ import unicode_literals

from dartcms.apps.users.models import UserGroup
from django.db import migrations


def add_user_group(apps, schema):
    UserGroup.objects.create(name='Users')


class Migration(migrations.Migration):
    dependencies = [
        ('users', '0002_auto_20161214_0258'),
    ]

    operations = [
        migrations.RunPython(add_user_group)
    ]
