{% load i18n %}

<div class="modal">
    {% block js %}{% endblock %}
    <div class="page-header">
        <h1>
            {{ page_header|capfirst }}
            <small>{% if read_only %}{% trans 'View Record' %}{% else %}{% trans 'Update Record' %}{% endif %} &laquo;{{ object }}&raquo;</small>
        </h1>
    </div>
    <div class="well well-sm">
        <form method="POST" class="form-horizontal" enctype="multipart/form-data">
            {% block form_content %}
                {% csrf_token %}
                {% include "dartcms/forms/horizontal.html" %}
                {% block additional_form_fields %}{% endblock %}
                <div class="form-group">
                    <div class="col-xs-9 col-xs-offset-3">
                        {% block form_actions %}
                            {% if not read_only %}<button type="submit" class="btn btn-primary">{% trans 'Update' %}</button>{% endif %}
                            <a href="#" class="btn btn-link btn-close-modal">{% trans 'Cancel' %}</a>
                        {% endblock %}
                    </div>
                </div>
            {% endblock %}
        </form>
    </div>
</div>
