# Generated by Django 1.9.9 on 2016-10-26 07:11
from __future__ import unicode_literals

import dartcms.utils.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0007_feedback_pagemodule'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='page',
            managers=[
            ],
        ),
        migrations.AlterField(
            model_name='page',
            name='after_content',
            field=dartcms.utils.fields.RteField(blank=True, default=b'', verbose_name='After Content'),
        ),
        migrations.AlterField(
            model_name='page',
            name='before_content',
            field=dartcms.utils.fields.RteField(blank=True, default=b'', verbose_name='Before Content'),
        ),
        migrations.AlterField(
            model_name='pagemodule',
            name='related_model',
            field=models.CharField(blank=True, default=None, max_length=32, null=True, verbose_name='Related Model'),
        ),
    ]
