# Generated by Django 1.10.4 on 2017-08-29 05:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('feedback', '0003_auto_20160801_1607'),
    ]

    operations = [
        migrations.AlterField(
            model_name='formtype',
            name='slug',
            field=models.SlugField(choices=[('contact', 'Contact form'), ('question', 'Questions form')], verbose_name='Type ID'),
        ),
    ]
