# Generated by Django 2.0.1 on 2018-01-30 12:17

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('sitesettings', '0003_auto_20170829_0515'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitesettings',
            name='boolean_value',
            field=models.BooleanField(default=False, verbose_name='Value for boolean'),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='content_type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType'),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='object_id',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='sitesettings',
            name='type',
            field=models.CharField(blank=True, choices=[('text', 'String'), ('textarea', 'Text'), ('rich', 'Rich Editor'), ('select', 'Select'), ('date', 'Date'), ('file', 'File'), ('object', 'Object'), ('boolean', 'Checkbox')], default='text', max_length=10, verbose_name='Type'),
        ),
    ]
