.icon-blank {
    background: url('icons/blank.gif') no-repeat center center;
}

.icon-add, .icon-load {
    background: url('icons/edit_add.png') no-repeat center center;
}

.icon-edit {
    background: url('icons/pencil.png') no-repeat center center;
}

.icon-remove {
    background: url('icons/edit_remove.png') no-repeat center center;
}

.icon-save {
    background: url('icons/filesave.png') no-repeat center center;
}

.icon-cut {
    background: url('icons/cut.png') no-repeat center center;
}

.icon-ok {
    background: url('icons/ok.png') no-repeat center center;
}

.icon-no {
    background: url('icons/no.png') no-repeat center center;
}

.icon-cancel {
    background: url('icons/cancel.png') no-repeat center center;
}

.icon-reload {
    background: url('icons/reload.png') no-repeat center center;
}

.icon-search {
    background: url('icons/search.png') no-repeat center center;
}

.icon-print {
    background: url('icons/print.png') no-repeat center center;
}

.icon-help {
    background: url('icons/help.png') no-repeat center center;
}

.icon-undo {
    background: url('icons/undo.png') no-repeat center center;
}

.icon-redo {
    background: url('icons/redo.png') no-repeat center center;
}

.icon-back {
    background: url('icons/back.png') no-repeat center center;
}

.icon-sum {
    background: url('icons/sum.png') no-repeat center center;
}

.icon-tip {
    background: url('icons/tip.png') no-repeat center center;
}

.icon-filter {
    background: url('icons/filter.png') no-repeat center center;
}

.icon-mini-add {
    background: url('icons/mini_add.png') no-repeat center center;
}

.icon-mini-edit {
    background: url('icons/mini_edit.png') no-repeat center center;
}

.icon-mini-refresh {
    background: url('icons/mini_refresh.png') no-repeat center center;
}

.icon-sort {
    background: url('icons/sort.png') no-repeat center center;
}

.icon-move {
    background: url('icons/move.png') no-repeat center center;
}

.icon-chevron {
    background: url('icons/chevron.png') no-repeat center center;
}

.icon-upload {
    background: url('icons/upload.png') no-repeat center center;
}

.icon-folder {
    background: url('icons/folder.png') no-repeat center center;
}

.icon-download {
    background: url('icons/download.png') no-repeat center center;
}

.icon-next {
    background: url('icons/next.png') no-repeat center center;
}

.icon-more {
    background: url('icons/more.png') no-repeat center center;
}