# Generated by Django 1.10.4 on 2016-12-14 03:36
from __future__ import unicode_literals

from dartcms.utils.loading import get_model
from django.db import migrations


def set_homepage_security(apps, schema):
    Page = get_model('pages', 'Page')
    Page.objects.filter(module__slug='homepage').update(security_type='DEFAULT')


class Migration(migrations.Migration):
    dependencies = [
        ('pages', '0011_insert_homepage'),
    ]

    operations = [
        migrations.RunPython(set_homepage_security)
    ]
