/*!
 * Bootstrap v3.3.6 (http://getbootstrap.com)
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 */
.btn-default,
.btn-primary,
.btn-success,
.btn-info,
.btn-warning,
.btn-danger {
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.2);
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.15), 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.15), 0 1px 1px rgba(0, 0, 0, 0.075);
}
.btn-default:active,
.btn-primary:active,
.btn-success:active,
.btn-info:active,
.btn-warning:active,
.btn-danger:active,
.btn-default.active,
.btn-primary.active,
.btn-success.active,
.btn-info.active,
.btn-warning.active,
.btn-danger.active {
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
.btn-default.disabled,
.btn-primary.disabled,
.btn-success.disabled,
.btn-info.disabled,
.btn-warning.disabled,
.btn-danger.disabled,
.btn-default[disabled],
.btn-primary[disabled],
.btn-success[disabled],
.btn-info[disabled],
.btn-warning[disabled],
.btn-danger[disabled],
fieldset[disabled] .btn-default,
fieldset[disabled] .btn-primary,
fieldset[disabled] .btn-success,
fieldset[disabled] .btn-info,
fieldset[disabled] .btn-warning,
fieldset[disabled] .btn-danger {
  -webkit-box-shadow: none;
  box-shadow: none;
}
.btn-default .badge,
.btn-primary .badge,
.btn-success .badge,
.btn-info .badge,
.btn-warning .badge,
.btn-danger .badge {
  text-shadow: none;
}
.btn:active,
.btn.active {
  background-image: none;
}
.btn-default {
  background-image: -webkit-linear-gradient(top, #474949 0%, #292a2a 100%);
  background-image: -o-linear-gradient(top, #474949 0%, #292a2a 100%);
  background-image: linear-gradient(to bottom, #474949 0%, #292a2a 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff474949', endColorstr='#ff292a2a', GradientType=0);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  background-repeat: repeat-x;
  border-color: #242525;
  text-shadow: 0 1px 0 #fff;
  border-color: #ccc;
}
.btn-default:hover,
.btn-default:focus {
  background-color: #292a2a;
  background-position: 0 -15px;
}
.btn-default:active,
.btn-default.active {
  background-color: #292a2a;
  border-color: #242525;
}
.btn-default.disabled,
.btn-default[disabled],
fieldset[disabled] .btn-default,
.btn-default.disabled:hover,
.btn-default[disabled]:hover,
fieldset[disabled] .btn-default:hover,
.btn-default.disabled:focus,
.btn-default[disabled]:focus,
fieldset[disabled] .btn-default:focus,
.btn-default.disabled.focus,
.btn-default[disabled].focus,
fieldset[disabled] .btn-default.focus,
.btn-default.disabled:active,
.btn-default[disabled]:active,
fieldset[disabled] .btn-default:active,
.btn-default.disabled.active,
.btn-default[disabled].active,
fieldset[disabled] .btn-default.active {
  background-color: #292a2a;
  background-image: none;
}
.btn-primary {
  background-image: -webkit-linear-gradient(top, #348fe2 0%, #1b70be 100%);
  background-image: -o-linear-gradient(top, #348fe2 0%, #1b70be 100%);
  background-image: linear-gradient(to bottom, #348fe2 0%, #1b70be 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff348fe2', endColorstr='#ff1b70be', GradientType=0);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  background-repeat: repeat-x;
  border-color: #1a6bb5;
}
.btn-primary:hover,
.btn-primary:focus {
  background-color: #1b70be;
  background-position: 0 -15px;
}
.btn-primary:active,
.btn-primary.active {
  background-color: #1b70be;
  border-color: #1a6bb5;
}
.btn-primary.disabled,
.btn-primary[disabled],
fieldset[disabled] .btn-primary,
.btn-primary.disabled:hover,
.btn-primary[disabled]:hover,
fieldset[disabled] .btn-primary:hover,
.btn-primary.disabled:focus,
.btn-primary[disabled]:focus,
fieldset[disabled] .btn-primary:focus,
.btn-primary.disabled.focus,
.btn-primary[disabled].focus,
fieldset[disabled] .btn-primary.focus,
.btn-primary.disabled:active,
.btn-primary[disabled]:active,
fieldset[disabled] .btn-primary:active,
.btn-primary.disabled.active,
.btn-primary[disabled].active,
fieldset[disabled] .btn-primary.active {
  background-color: #1b70be;
  background-image: none;
}
.btn-success {
  background-image: -webkit-linear-gradient(top, #00acac 0%, #006f6f 100%);
  background-image: -o-linear-gradient(top, #00acac 0%, #006f6f 100%);
  background-image: linear-gradient(to bottom, #00acac 0%, #006f6f 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff00acac', endColorstr='#ff006f6f', GradientType=0);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  background-repeat: repeat-x;
  border-color: #006565;
}
.btn-success:hover,
.btn-success:focus {
  background-color: #006f6f;
  background-position: 0 -15px;
}
.btn-success:active,
.btn-success.active {
  background-color: #006f6f;
  border-color: #006565;
}
.btn-success.disabled,
.btn-success[disabled],
fieldset[disabled] .btn-success,
.btn-success.disabled:hover,
.btn-success[disabled]:hover,
fieldset[disabled] .btn-success:hover,
.btn-success.disabled:focus,
.btn-success[disabled]:focus,
fieldset[disabled] .btn-success:focus,
.btn-success.disabled.focus,
.btn-success[disabled].focus,
fieldset[disabled] .btn-success.focus,
.btn-success.disabled:active,
.btn-success[disabled]:active,
fieldset[disabled] .btn-success:active,
.btn-success.disabled.active,
.btn-success[disabled].active,
fieldset[disabled] .btn-success.active {
  background-color: #006f6f;
  background-image: none;
}
.btn-info {
  background-image: -webkit-linear-gradient(top, #49b6d6 0%, #2a98b8 100%);
  background-image: -o-linear-gradient(top, #49b6d6 0%, #2a98b8 100%);
  background-image: linear-gradient(to bottom, #49b6d6 0%, #2a98b8 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff49b6d6', endColorstr='#ff2a98b8', GradientType=0);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  background-repeat: repeat-x;
  border-color: #2891b0;
}
.btn-info:hover,
.btn-info:focus {
  background-color: #2a98b8;
  background-position: 0 -15px;
}
.btn-info:active,
.btn-info.active {
  background-color: #2a98b8;
  border-color: #2891b0;
}
.btn-info.disabled,
.btn-info[disabled],
fieldset[disabled] .btn-info,
.btn-info.disabled:hover,
.btn-info[disabled]:hover,
fieldset[disabled] .btn-info:hover,
.btn-info.disabled:focus,
.btn-info[disabled]:focus,
fieldset[disabled] .btn-info:focus,
.btn-info.disabled.focus,
.btn-info[disabled].focus,
fieldset[disabled] .btn-info.focus,
.btn-info.disabled:active,
.btn-info[disabled]:active,
fieldset[disabled] .btn-info:active,
.btn-info.disabled.active,
.btn-info[disabled].active,
fieldset[disabled] .btn-info.active {
  background-color: #2a98b8;
  background-image: none;
}
.btn-warning {
  background-image: -webkit-linear-gradient(top, #f59c1a 0%, #c97b09 100%);
  background-image: -o-linear-gradient(top, #f59c1a 0%, #c97b09 100%);
  background-image: linear-gradient(to bottom, #f59c1a 0%, #c97b09 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff59c1a', endColorstr='#ffc97b09', GradientType=0);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  background-repeat: repeat-x;
  border-color: #bf7508;
}
.btn-warning:hover,
.btn-warning:focus {
  background-color: #c97b09;
  background-position: 0 -15px;
}
.btn-warning:active,
.btn-warning.active {
  background-color: #c97b09;
  border-color: #bf7508;
}
.btn-warning.disabled,
.btn-warning[disabled],
fieldset[disabled] .btn-warning,
.btn-warning.disabled:hover,
.btn-warning[disabled]:hover,
fieldset[disabled] .btn-warning:hover,
.btn-warning.disabled:focus,
.btn-warning[disabled]:focus,
fieldset[disabled] .btn-warning:focus,
.btn-warning.disabled.focus,
.btn-warning[disabled].focus,
fieldset[disabled] .btn-warning.focus,
.btn-warning.disabled:active,
.btn-warning[disabled]:active,
fieldset[disabled] .btn-warning:active,
.btn-warning.disabled.active,
.btn-warning[disabled].active,
fieldset[disabled] .btn-warning.active {
  background-color: #c97b09;
  background-image: none;
}
.btn-danger {
  background-image: -webkit-linear-gradient(top, #ff5b57 0%, #ff1f1a 100%);
  background-image: -o-linear-gradient(top, #ff5b57 0%, #ff1f1a 100%);
  background-image: linear-gradient(to bottom, #ff5b57 0%, #ff1f1a 100%);
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffff5b57', endColorstr='#ffff1f1a', GradientType=0);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  background-repeat: repeat-x;
  border-color: #ff1510;
}
.btn-danger:hover,
.btn-danger:focus {
  background-color: #ff1f1a;
  background-position: 0 -15px;
}
.btn-danger:active,
.btn-danger.active {
  background-color: #ff1f1a;
  border-color: #ff1510;
}
.btn-danger.disabled,
.btn-danger[disabled],
fieldset[disabled] .btn-danger,
.btn-danger.disabled:hover,
.btn-danger[disabled]:hover,
fieldset[disabled] .btn-danger:hover,
.btn-danger.disabled:focus,
.btn-danger[disabled]:focus,
fieldset[disabled] .btn-danger:focus,
.btn-danger.disabled.focus,
.btn-danger[disabled].focus,
fieldset[disabled] .btn-danger.focus,
.btn-danger.disabled:active,
.btn-danger[disabled]:active,
fieldset[disabled] .btn-danger:active,
.btn-danger.disabled.active,
.btn-danger[disabled].active,
fieldset[disabled] .btn-danger.active {
  background-color: #ff1f1a;
  background-image: none;
}
.thumbnail,
.img-thumbnail {
  -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.075);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.075);
}
.dropdown-menu > li > a:hover,
.dropdown-menu > li > a:focus {
  background-image: -webkit-linear-gradient(top, #348fe2 0%, #2083dd 100%);
  background-image: -o-linear-gradient(top, #348fe2 0%, #2083dd 100%);
  background-image: linear-gradient(to bottom, #348fe2 0%, #2083dd 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff348fe2', endColorstr='#ff2083dd', GradientType=0);
  background-color: #2083dd;
}
.dropdown-menu > .active > a,
.dropdown-menu > .active > a:hover,
.dropdown-menu > .active > a:focus {
  background-image: -webkit-linear-gradient(top, #348fe2 0%, #2083dd 100%);
  background-image: -o-linear-gradient(top, #348fe2 0%, #2083dd 100%);
  background-image: linear-gradient(to bottom, #348fe2 0%, #2083dd 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff348fe2', endColorstr='#ff2083dd', GradientType=0);
  background-color: #2083dd;
}
.navbar-default {
  background-image: -webkit-linear-gradient(top, #ffffff 0%, #fff 100%);
  background-image: -o-linear-gradient(top, #ffffff 0%, #fff 100%);
  background-image: linear-gradient(to bottom, #ffffff 0%, #fff 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffffff', endColorstr='#ffffffff', GradientType=0);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  border-radius: 0;
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.15), 0 1px 5px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.15), 0 1px 5px rgba(0, 0, 0, 0.075);
}
.navbar-default .navbar-nav > .open > a,
.navbar-default .navbar-nav > .active > a {
  background-image: -webkit-linear-gradient(top, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0) 100%);
  background-image: -o-linear-gradient(top, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0) 100%);
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 0) 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00000000', endColorstr='#00000000', GradientType=0);
  -webkit-box-shadow: inset 0 3px 9px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 3px 9px rgba(0, 0, 0, 0.075);
}
.navbar-brand,
.navbar-nav > li > a {
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.25);
}
.navbar-inverse {
  background-image: -webkit-linear-gradient(top, #61a8e8 0%, #348fe2 100%);
  background-image: -o-linear-gradient(top, #61a8e8 0%, #348fe2 100%);
  background-image: linear-gradient(to bottom, #61a8e8 0%, #348fe2 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff61a8e8', endColorstr='#ff348fe2', GradientType=0);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  border-radius: 0;
}
.navbar-inverse .navbar-nav > .open > a,
.navbar-inverse .navbar-nav > .active > a {
  background-image: -webkit-linear-gradient(top, transparent 0%, rgba(6, 6, 6, 0) 100%);
  background-image: -o-linear-gradient(top, transparent 0%, rgba(6, 6, 6, 0) 100%);
  background-image: linear-gradient(to bottom, transparent 0%, rgba(6, 6, 6, 0) 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00000000', endColorstr='#00060606', GradientType=0);
  -webkit-box-shadow: inset 0 3px 9px rgba(0, 0, 0, 0.25);
  box-shadow: inset 0 3px 9px rgba(0, 0, 0, 0.25);
}
.navbar-inverse .navbar-brand,
.navbar-inverse .navbar-nav > li > a {
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
}
.navbar-static-top,
.navbar-fixed-top,
.navbar-fixed-bottom {
  border-radius: 0;
}
@media (max-width: 767px) {
  .navbar .navbar-nav .open .dropdown-menu > .active > a,
  .navbar .navbar-nav .open .dropdown-menu > .active > a:hover,
  .navbar .navbar-nav .open .dropdown-menu > .active > a:focus {
    color: #fff;
    background-image: -webkit-linear-gradient(top, #348fe2 0%, #2083dd 100%);
    background-image: -o-linear-gradient(top, #348fe2 0%, #2083dd 100%);
    background-image: linear-gradient(to bottom, #348fe2 0%, #2083dd 100%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff348fe2', endColorstr='#ff2083dd', GradientType=0);
  }
}
.alert {
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.2);
  -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.25), 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.25), 0 1px 2px rgba(0, 0, 0, 0.05);
}
.alert-success {
  background-image: -webkit-linear-gradient(top, #00acac 0%, #008686 100%);
  background-image: -o-linear-gradient(top, #00acac 0%, #008686 100%);
  background-image: linear-gradient(to bottom, #00acac 0%, #008686 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff00acac', endColorstr='#ff008686', GradientType=0);
  border-color: #005f60;
}
.alert-info {
  background-image: -webkit-linear-gradient(top, #49b6d6 0%, #2ea7cb 100%);
  background-image: -o-linear-gradient(top, #49b6d6 0%, #2ea7cb 100%);
  background-image: linear-gradient(to bottom, #49b6d6 0%, #2ea7cb 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff49b6d6', endColorstr='#ff2ea7cb', GradientType=0);
  border-color: #278eac;
}
.alert-warning {
  background-image: -webkit-linear-gradient(top, #f59c1a 0%, #df880a 100%);
  background-image: -o-linear-gradient(top, #f59c1a 0%, #df880a 100%);
  background-image: linear-gradient(to bottom, #f59c1a 0%, #df880a 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff59c1a', endColorstr='#ffdf880a', GradientType=0);
  border-color: #ba7208;
}
.alert-danger {
  background-image: -webkit-linear-gradient(top, #ff5b57 0%, #ff3631 100%);
  background-image: -o-linear-gradient(top, #ff5b57 0%, #ff3631 100%);
  background-image: linear-gradient(to bottom, #ff5b57 0%, #ff3631 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffff5b57', endColorstr='#ffff3631', GradientType=0);
  border-color: #ff100b;
}
.progress {
  background-image: -webkit-linear-gradient(top, #ebebeb 0%, #f5f5f5 100%);
  background-image: -o-linear-gradient(top, #ebebeb 0%, #f5f5f5 100%);
  background-image: linear-gradient(to bottom, #ebebeb 0%, #f5f5f5 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffebebeb', endColorstr='#fff5f5f5', GradientType=0);
}
.progress-bar {
  background-image: -webkit-linear-gradient(top, #348fe2 0%, #1c75c7 100%);
  background-image: -o-linear-gradient(top, #348fe2 0%, #1c75c7 100%);
  background-image: linear-gradient(to bottom, #348fe2 0%, #1c75c7 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff348fe2', endColorstr='#ff1c75c7', GradientType=0);
}
.progress-bar-success {
  background-image: -webkit-linear-gradient(top, #00acac 0%, #007979 100%);
  background-image: -o-linear-gradient(top, #00acac 0%, #007979 100%);
  background-image: linear-gradient(to bottom, #00acac 0%, #007979 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff00acac', endColorstr='#ff007979', GradientType=0);
}
.progress-bar-info {
  background-image: -webkit-linear-gradient(top, #49b6d6 0%, #2b9fc1 100%);
  background-image: -o-linear-gradient(top, #49b6d6 0%, #2b9fc1 100%);
  background-image: linear-gradient(to bottom, #49b6d6 0%, #2b9fc1 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff49b6d6', endColorstr='#ff2b9fc1', GradientType=0);
}
.progress-bar-warning {
  background-image: -webkit-linear-gradient(top, #f59c1a 0%, #d38109 100%);
  background-image: -o-linear-gradient(top, #f59c1a 0%, #d38109 100%);
  background-image: linear-gradient(to bottom, #f59c1a 0%, #d38109 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff59c1a', endColorstr='#ffd38109', GradientType=0);
}
.progress-bar-danger {
  background-image: -webkit-linear-gradient(top, #ff5b57 0%, #ff2924 100%);
  background-image: -o-linear-gradient(top, #ff5b57 0%, #ff2924 100%);
  background-image: linear-gradient(to bottom, #ff5b57 0%, #ff2924 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffff5b57', endColorstr='#ffff2924', GradientType=0);
}
.progress-bar-striped {
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.list-group {
  border-radius: 4px;
  -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.075);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.075);
}
.list-group-item.active,
.list-group-item.active:hover,
.list-group-item.active:focus {
  text-shadow: 0 -1px 0 #1c75c7;
  background-image: -webkit-linear-gradient(top, #348fe2 0%, #1e7cd2 100%);
  background-image: -o-linear-gradient(top, #348fe2 0%, #1e7cd2 100%);
  background-image: linear-gradient(to bottom, #348fe2 0%, #1e7cd2 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff348fe2', endColorstr='#ff1e7cd2', GradientType=0);
  border-color: #1e7cd2;
}
.list-group-item.active .badge,
.list-group-item.active:hover .badge,
.list-group-item.active:focus .badge {
  text-shadow: none;
}
.panel {
  -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
}
.panel-default > .panel-heading {
  background-image: -webkit-linear-gradient(top, #FCFCFC 0%, #efefef 100%);
  background-image: -o-linear-gradient(top, #FCFCFC 0%, #efefef 100%);
  background-image: linear-gradient(to bottom, #FCFCFC 0%, #efefef 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fffcfcfc', endColorstr='#ffefefef', GradientType=0);
}
.panel-primary > .panel-heading {
  background-image: -webkit-linear-gradient(top, #348fe2 0%, #2083dd 100%);
  background-image: -o-linear-gradient(top, #348fe2 0%, #2083dd 100%);
  background-image: linear-gradient(to bottom, #348fe2 0%, #2083dd 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff348fe2', endColorstr='#ff2083dd', GradientType=0);
}
.panel-success > .panel-heading {
  background-image: -webkit-linear-gradient(top, #00acac 0%, #009393 100%);
  background-image: -o-linear-gradient(top, #00acac 0%, #009393 100%);
  background-image: linear-gradient(to bottom, #00acac 0%, #009393 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff00acac', endColorstr='#ff009393', GradientType=0);
}
.panel-info > .panel-heading {
  background-image: -webkit-linear-gradient(top, #49b6d6 0%, #34aed1 100%);
  background-image: -o-linear-gradient(top, #49b6d6 0%, #34aed1 100%);
  background-image: linear-gradient(to bottom, #49b6d6 0%, #34aed1 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff49b6d6', endColorstr='#ff34aed1', GradientType=0);
}
.panel-warning > .panel-heading {
  background-image: -webkit-linear-gradient(top, #f59c1a 0%, #eb900a 100%);
  background-image: -o-linear-gradient(top, #f59c1a 0%, #eb900a 100%);
  background-image: linear-gradient(to bottom, #f59c1a 0%, #eb900a 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff59c1a', endColorstr='#ffeb900a', GradientType=0);
}
.panel-danger > .panel-heading {
  background-image: -webkit-linear-gradient(top, #ff5b57 0%, #ff423e 100%);
  background-image: -o-linear-gradient(top, #ff5b57 0%, #ff423e 100%);
  background-image: linear-gradient(to bottom, #ff5b57 0%, #ff423e 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffff5b57', endColorstr='#ffff423e', GradientType=0);
}
.well {
  background-image: -webkit-linear-gradient(top, #f2f2f2 0%, #fff 100%);
  background-image: -o-linear-gradient(top, #f2f2f2 0%, #fff 100%);
  background-image: linear-gradient(to bottom, #f2f2f2 0%, #fff 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fff2f2f2', endColorstr='#ffffffff', GradientType=0);
  border-color: #e6e6e6;
  -webkit-box-shadow: inset 0 1px 3px rgba(0, 0, 0, 0.05), 0 1px 0 rgba(255, 255, 255, 0.1);
  box-shadow: inset 0 1px 3px rgba(0, 0, 0, 0.05), 0 1px 0 rgba(255, 255, 255, 0.1);
}
/*# sourceMappingURL=bootstrap-theme.css.map */