# Generated by Django 3.2.8 on 2021-10-08 12:46

from django.db import migrations


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('user', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='SiteUser',
            fields=[
            ],
            options={
                'verbose_name': 'Site User',
                'verbose_name_plural': 'Site Users',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('user.user',),
        ),
    ]
