# Generated by Django 2.0.1 on 2018-02-14 13:42

import versatileimagefield.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0009_auto_20180123_1113'),
    ]

    operations = [
        migrations.AlterField(
            model_name='product',
            name='image',
            field=versatileimagefield.fields.VersatileImageField(blank=True, null=True, upload_to='shop/product/%Y/%m/%d', verbose_name='Image'),
        ),
        migrations.AlterField(
            model_name='productcatalog',
            name='image',
            field=versatileimagefield.fields.VersatileImageField(blank=True, null=True, upload_to='shop/catalog', verbose_name='Image'),
        ),
        migrations.AlterField(
            model_name='productimage',
            name='image',
            field=versatileimagefield.fields.VersatileImageField(upload_to='shop/product_images/%Y/%m/%d', verbose_name='Image'),
        ),
        migrations.AlterField(
            model_name='productlabel',
            name='image',
            field=versatileimagefield.fields.VersatileImageField(blank=True, null=True, upload_to='shop/label', verbose_name='Image'),
        ),
        migrations.AlterField(
            model_name='productmanufacturer',
            name='image',
            field=versatileimagefield.fields.VersatileImageField(blank=True, null=True, upload_to='shop/producer', verbose_name='Image'),
        ),
        migrations.AlterField(
            model_name='productsection',
            name='image',
            field=versatileimagefield.fields.VersatileImageField(blank=True, null=True, upload_to='shop/section', verbose_name='Image'),
        ),
    ]
