{% extends 'dartcms/base/index.html' %}

{% load i18n %}

{% block page_content %}
    <div class="page-header">
        <h1>{% trans 'DartCMS Dashboard' %}</h1>
    </div>
    <div class="well">
        <p></p>

        <p>{% trans 'Welcome to DartCMS, your content management system.' %}</p>
    </div>
{% endblock %}