# Generated by Django 2.0.1 on 2018-01-23 11:13

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0009_alter_user_last_name_max_length'),
        ('users', '0003_user_group'),
    ]

    operations = [
        migrations.CreateModel(
            name='CMSUser',
            fields=[
            ],
            options={
                'verbose_name': 'CMS User',
                'verbose_name_plural': 'CMS Users',
                'proxy': True,
                'indexes': [],
            },
            bases=(settings.AUTH_USER_MODEL,),
        ),
    ]
