tinymce.addI18n('ja', {
    'Icons': 'Icon',
    'Web Application': '一般',
    'File Type': 'ファイルタイプ',
    'Spinner': 'スピナー（回転）', 
    'Form Control': 'フォーム･コントロール',
    'Currency': '通貨',
    'Text Editor': 'エディタ',
    'Directional': '矢印・方向',
    'Video Player': 'プレイヤー',
    'Brand': 'ブランド',
    'Medical': '医療',
    'Transportation': '交通',
    'Gender': '性',
    'Payment': '支払い',
    'Chart': 'チャート',
    'Hand': '手',
    'Search': '検索',
    'No icons matched your search': 'いいえアイコンは、検索条件に一致しません'
});
