# Generated by Django 1.10.4 on 2017-08-29 05:15
from __future__ import unicode_literals

import autoslug.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('feeds', '0005_auto_20160801_1607'),
    ]

    operations = [
        migrations.AlterField(
            model_name='feeditem',
            name='picture',
            field=models.ImageField(blank=True, null=True, upload_to='feeds/%Y/%m/%d', verbose_name='Picture'),
        ),
        migrations.AlterField(
            model_name='feeditem',
            name='slug',
            field=autoslug.fields.AutoSlugField(editable=False, populate_from='name', unique=True, verbose_name='URL'),
        ),
    ]
