# Generated by Django 1.10.4 on 2017-08-29 05:15
from __future__ import unicode_literals

import autoslug.fields
import dartcms.utils.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0007_runtime_config'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='order',
            options={'ordering': ['-date_created'], 'verbose_name': 'order', 'verbose_name_plural': 'orders'},
        ),
        migrations.AlterModelOptions(
            name='orderdetail',
            options={'ordering': ['name'], 'verbose_name': 'order datail', 'verbose_name_plural': 'order datails'},
        ),
        migrations.AlterModelManagers(
            name='productsection',
            managers=[
            ],
        ),
        migrations.RemoveField(
            model_name='order',
            name='user',
        ),
        migrations.AlterField(
            model_name='order',
            name='date_created',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Date created'),
        ),
        migrations.AlterField(
            model_name='orderpaymenttype',
            name='description',
            field=dartcms.utils.fields.RteField(blank=True, default='', verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='ordershippingtype',
            name='description',
            field=dartcms.utils.fields.RteField(blank=True, default='', verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='orderstatus',
            name='description',
            field=dartcms.utils.fields.RteField(blank=True, default='', verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='product',
            name='code',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='Code'),
        ),
        migrations.AlterField(
            model_name='product',
            name='description',
            field=dartcms.utils.fields.RteField(blank=True, default='', verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='product',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to='shop/product/%Y/%m/%d', verbose_name='Image'),
        ),
        migrations.AlterField(
            model_name='product',
            name='seo_description',
            field=models.TextField(blank=True, default='', verbose_name='Description (meta description)'),
        ),
        migrations.AlterField(
            model_name='product',
            name='seo_keywords',
            field=models.TextField(blank=True, default='', verbose_name='Keywords (meta keywords)'),
        ),
        migrations.AlterField(
            model_name='product',
            name='short_description',
            field=dartcms.utils.fields.RteField(blank=True, default='', verbose_name='Short description'),
        ),
        migrations.AlterField(
            model_name='product',
            name='slug',
            field=autoslug.fields.AutoSlugField(editable=False, populate_from='name', unique=True, verbose_name='URL'),
        ),
        migrations.AlterField(
            model_name='productcatalog',
            name='description',
            field=dartcms.utils.fields.RteField(blank=True, default='', verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='productcatalog',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to='shop/catalog', verbose_name='Image'),
        ),
        migrations.AlterField(
            model_name='productcatalog',
            name='seo_description',
            field=models.TextField(blank=True, default='', verbose_name='Description (meta description)'),
        ),
        migrations.AlterField(
            model_name='productcatalog',
            name='seo_keywords',
            field=models.TextField(blank=True, default='', verbose_name='Keywords (meta keywords)'),
        ),
        migrations.AlterField(
            model_name='productimage',
            name='image',
            field=models.ImageField(upload_to='shop/product_images/%Y/%m/%d', verbose_name='Image'),
        ),
        migrations.AlterField(
            model_name='productlabel',
            name='description',
            field=dartcms.utils.fields.RteField(blank=True, default='', verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='productlabel',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to='shop/label', verbose_name='Image'),
        ),
        migrations.AlterField(
            model_name='productlabel',
            name='seo_description',
            field=models.TextField(blank=True, default='', verbose_name='Description (meta description)'),
        ),
        migrations.AlterField(
            model_name='productlabel',
            name='seo_keywords',
            field=models.TextField(blank=True, default='', verbose_name='Keywords (meta keywords)'),
        ),
        migrations.AlterField(
            model_name='productmanufacturer',
            name='description',
            field=dartcms.utils.fields.RteField(blank=True, default='', verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='productmanufacturer',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to='shop/producer', verbose_name='Image'),
        ),
        migrations.AlterField(
            model_name='productmanufacturer',
            name='seo_description',
            field=models.TextField(blank=True, default='', verbose_name='Description (meta description)'),
        ),
        migrations.AlterField(
            model_name='productmanufacturer',
            name='seo_keywords',
            field=models.TextField(blank=True, default='', verbose_name='Keywords (meta keywords)'),
        ),
        migrations.AlterField(
            model_name='productmanufacturer',
            name='slug',
            field=autoslug.fields.AutoSlugField(editable=False, populate_from='name', unique=True, verbose_name='URL'),
        ),
        migrations.AlterField(
            model_name='productsection',
            name='description',
            field=dartcms.utils.fields.RteField(blank=True, default='', verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='productsection',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to='shop/section', verbose_name='Image'),
        ),
        migrations.AlterField(
            model_name='productsection',
            name='seo_description',
            field=models.TextField(blank=True, default='', verbose_name='Description (meta description)'),
        ),
        migrations.AlterField(
            model_name='productsection',
            name='seo_keywords',
            field=models.TextField(blank=True, default='', verbose_name='Keywords (meta keywords)'),
        ),
        migrations.AlterField(
            model_name='productsection',
            name='slug',
            field=autoslug.fields.AutoSlugField(editable=False, populate_from='name', unique=True, verbose_name='URL'),
        ),
    ]
