{% load i18n %}

<div class="modal">
    <div class="page-header">
        <h1>{{ page_header|capfirst }}
            {% if object %}
                <small>{% trans 'Delete Record' %} &laquo;{{ object }}&raquo;</small>
            {% else %}
                <small>{% trans 'Delete' %} {{ count_records }} {% trans 'Records' %}</small>
            {% endif %}
        </h1>
    </div>
    <div class="well well-sm">
        {% block form %}
            <form method="POST" class="form-horizontal">
                {% csrf_token %}
                <div class="alert alert-danger">
                    <i class="fa fa-warning"></i> {% trans 'Deletion is permanent. Are you sure?' %}
                </div>
                <button type="submit" class="btn btn-danger">{% trans 'Yes' %}</button>
                <a href="#" class="btn btn-link btn-close-modal">{% trans 'Cancel' %}</a>
            </form>
        {% endblock %}
    </div>
</div>
