# Generated by Django 2.1.3 on 2018-11-14 10:21

from django.db import migrations
import versatileimagefield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('ads', '0002_auto_20170829_0515'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ad',
            name='picture',
            field=versatileimagefield.fields.VersatileImageField(blank=True, null=True, upload_to='b/%Y/%m/%d', verbose_name='Picture'),
        ),
    ]
