.user-permissions-widget {
  .module-group {
    padding: 10px;
    border-radius: 3px;
    border: 1px solid #e4e4e4;
    margin-bottom: 10px;

    .module-group-name {
      font-weight: bold;
    }

    .module-permissions {
      margin-bottom: 10px;

      .module-name, .module-permission {
        float: left;
      }

      .module-name {
        padding: 10px 20px 10px 0;
        width: 250px;
        text-align: right;
      }

      .module-permission {
        padding-right: 20px;
      }
    }
  }
}