{% extends 'dartcms/views/insert.html' %}

{% load static i18n %}

{% block js %}
    {{ block.super }}
    <script type="text/javascript" src="{% static 'dartcms/js/apps/pages/form.js' %}"></script>
{% endblock %}

{% block form_content %}
    {% if has_perm %}
        {{ block.super }}
        <div id="id-context-variables" data-loading-url="{% url 'dartcms:pages:load_module_params' %}"></div>
    {% else %}
        {% trans 'You do not have permission to add page in this section.' as security_message %}
        {% include 'dartcms/views/partials/security_alert.html' with message=security_message %}
    {% endif %}
{% endblock %}