# Generated by Django 1.9.9 on 2016-11-30 12:07
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0008_auto_20161026_0711'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='pagemodule',
            options={'ordering': ['name'], 'verbose_name': 'module', 'verbose_name_plural': 'modules'},
        ),
    ]
