# Generated by Django 2.0.1 on 2018-01-23 11:13

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('feeds', '0006_auto_20170829_0515'),
    ]

    operations = [
        migrations.AlterField(
            model_name='feed',
            name='type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='feeds', to='feeds.FeedType', verbose_name='Type'),
        ),
    ]
