{% extends 'dartcms/views/update.html' %}

{% load static i18n %}

{% block js %}
    {{ block.super }}
    <script type="text/javascript" src="{% static 'dartcms/js/apps/pages/form.js' %}"></script>
{% endblock %}

{% block form_content %}
    {% if not has_perm %}
        {% trans 'You do not have permission to edit this page.' as security_message %}
        {% include 'dartcms/views/partials/security_alert.html' with message=security_message hide_cancel=True %}
        <script>
            $('form').find('input, textarea, button, select').attr('disabled', 'disabled');
        </script>
    {% endif %}

    {{ block.super }}
    <div id="id-context-variables" data-page-pk="{{ object.pk }}"
         data-loading-url="{% url 'dartcms:pages:load_module_params' %}"></div>
{% endblock %}