body {
  background: #d9e0e7;
}

.content {
  padding-left: 260px;

  @media screen and (max-width: 1024px) {
    padding-left: 0;
  }
}

.page-content {
  padding: 0 20px;
}

div.mce-fullscreen {
    position: fixed;
    top: 0;
    left: 0;
    right: 0;
    width: auto !important;
    margin-left: 260px;
}
