/**
 * EasyUI for jQuery 1.5.4.1
 * 
 * Copyright (c) 2009-2018 www.jeasyui.com. All rights reserved.
 *
 * Licensed under the freeware license: http://www.jeasyui.com/license_freeware.php
 * To use it on other terms please contact us: info@jeasyui.com
 *
 */
(function($){
var _1=0;
function _2(a,o){
return $.easyui.indexOfArray(a,o);
};
function _3(a,o,id){
$.easyui.removeArrayItem(a,o,id);
};
function _4(a,o,r){
$.easyui.addArrayItem(a,o,r);
};
function _5(_6,aa){
return $.data(_6,"treegrid")?aa.slice(1):aa;
};
function _7(_8){
var _9=$.data(_8,"datagrid");
var _a=_9.options;
var _b=_9.panel;
var dc=_9.dc;
var ss=null;
if(_a.sharedStyleSheet){
ss=typeof _a.sharedStyleSheet=="boolean"?"head":_a.sharedStyleSheet;
}else{
ss=_b.closest("div.datagrid-view");
if(!ss.length){
ss=dc.view;
}
}
var cc=$(ss);
var _c=$.data(cc[0],"ss");
if(!_c){
_c=$.data(cc[0],"ss",{cache:{},dirty:[]});
}
return {add:function(_d){
var ss=["<style type=\"text/css\" easyui=\"true\">"];
for(var i=0;i<_d.length;i++){
_c.cache[_d[i][0]]={width:_d[i][1]};
}
var _e=0;
for(var s in _c.cache){
var _f=_c.cache[s];
_f.index=_e++;
ss.push(s+"{width:"+_f.width+"}");
}
ss.push("</style>");
$(ss.join("\n")).appendTo(cc);
cc.children("style[easyui]:not(:last)").remove();
},getRule:function(_10){
var _11=cc.children("style[easyui]:last")[0];
var _12=_11.styleSheet?_11.styleSheet:(_11.sheet||document.styleSheets[document.styleSheets.length-1]);
var _13=_12.cssRules||_12.rules;
return _13[_10];
},set:function(_14,_15){
var _16=_c.cache[_14];
if(_16){
_16.width=_15;
var _17=this.getRule(_16.index);
if(_17){
_17.style["width"]=_15;
}
}
},remove:function(_18){
var tmp=[];
for(var s in _c.cache){
if(s.indexOf(_18)==-1){
tmp.push([s,_c.cache[s].width]);
}
}
_c.cache={};
this.add(tmp);
},dirty:function(_19){
if(_19){
_c.dirty.push(_19);
}
},clean:function(){
for(var i=0;i<_c.dirty.length;i++){
this.remove(_c.dirty[i]);
}
_c.dirty=[];
}};
};
function _1a(_1b,_1c){
var _1d=$.data(_1b,"datagrid");
var _1e=_1d.options;
var _1f=_1d.panel;
if(_1c){
$.extend(_1e,_1c);
}
if(_1e.fit==true){
var p=_1f.panel("panel").parent();
_1e.width=p.width();
_1e.height=p.height();
}
_1f.panel("resize",_1e);
};
function _20(_21){
var _22=$.data(_21,"datagrid");
var _23=_22.options;
var dc=_22.dc;
var _24=_22.panel;
var _25=_24.width();
var _26=_24.height();
var _27=dc.view;
var _28=dc.view1;
var _29=dc.view2;
var _2a=_28.children("div.datagrid-header");
var _2b=_29.children("div.datagrid-header");
var _2c=_2a.find("table");
var _2d=_2b.find("table");
_27.width(_25);
var _2e=_2a.children("div.datagrid-header-inner").show();
_28.width(_2e.find("table").width());
if(!_23.showHeader){
_2e.hide();
}
_29.width(_25-_28._outerWidth());
_28.children()._outerWidth(_28.width());
_29.children()._outerWidth(_29.width());
var all=_2a.add(_2b).add(_2c).add(_2d);
all.css("height","");
var hh=Math.max(_2c.height(),_2d.height());
all._outerHeight(hh);
_27.children(".datagrid-empty").css("top",hh+"px");
dc.body1.add(dc.body2).children("table.datagrid-btable-frozen").css({position:"absolute",top:dc.header2._outerHeight()});
var _2f=dc.body2.children("table.datagrid-btable-frozen")._outerHeight();
var _30=_2f+_2b._outerHeight()+_29.children(".datagrid-footer")._outerHeight();
_24.children(":not(.datagrid-view,.datagrid-mask,.datagrid-mask-msg)").each(function(){
_30+=$(this)._outerHeight();
});
var _31=_24.outerHeight()-_24.height();
var _32=_24._size("minHeight")||"";
var _33=_24._size("maxHeight")||"";
_28.add(_29).children("div.datagrid-body").css({marginTop:_2f,height:(isNaN(parseInt(_23.height))?"":(_26-_30)),minHeight:(_32?_32-_31-_30:""),maxHeight:(_33?_33-_31-_30:"")});
_27.height(_29.height());
};
function _34(_35,_36,_37){
var _38=$.data(_35,"datagrid").data.rows;
var _39=$.data(_35,"datagrid").options;
var dc=$.data(_35,"datagrid").dc;
if(!dc.body1.is(":empty")&&(!_39.nowrap||_39.autoRowHeight||_37)){
if(_36!=undefined){
var tr1=_39.finder.getTr(_35,_36,"body",1);
var tr2=_39.finder.getTr(_35,_36,"body",2);
_3a(tr1,tr2);
}else{
var tr1=_39.finder.getTr(_35,0,"allbody",1);
var tr2=_39.finder.getTr(_35,0,"allbody",2);
_3a(tr1,tr2);
if(_39.showFooter){
var tr1=_39.finder.getTr(_35,0,"allfooter",1);
var tr2=_39.finder.getTr(_35,0,"allfooter",2);
_3a(tr1,tr2);
}
}
}
_20(_35);
if(_39.height=="auto"){
var _3b=dc.body1.parent();
var _3c=dc.body2;
var _3d=_3e(_3c);
var _3f=_3d.height;
if(_3d.width>_3c.width()){
_3f+=18;
}
_3f-=parseInt(_3c.css("marginTop"))||0;
_3b.height(_3f);
_3c.height(_3f);
dc.view.height(dc.view2.height());
}
dc.body2.triggerHandler("scroll");
function _3a(_40,_41){
for(var i=0;i<_41.length;i++){
var tr1=$(_40[i]);
var tr2=$(_41[i]);
tr1.css("height","");
tr2.css("height","");
var _42=Math.max(tr1.height(),tr2.height());
tr1.css("height",_42);
tr2.css("height",_42);
}
};
function _3e(cc){
var _43=0;
var _44=0;
$(cc).children().each(function(){
var c=$(this);
if(c.is(":visible")){
_44+=c._outerHeight();
if(_43<c._outerWidth()){
_43=c._outerWidth();
}
}
});
return {width:_43,height:_44};
};
};
function _45(_46,_47){
var _48=$.data(_46,"datagrid");
var _49=_48.options;
var dc=_48.dc;
if(!dc.body2.children("table.datagrid-btable-frozen").length){
dc.body1.add(dc.body2).prepend("<table class=\"datagrid-btable datagrid-btable-frozen\" cellspacing=\"0\" cellpadding=\"0\"></table>");
}
_4a(true);
_4a(false);
_20(_46);
function _4a(_4b){
var _4c=_4b?1:2;
var tr=_49.finder.getTr(_46,_47,"body",_4c);
(_4b?dc.body1:dc.body2).children("table.datagrid-btable-frozen").append(tr);
};
};
function _4d(_4e,_4f){
function _50(){
var _51=[];
var _52=[];
$(_4e).children("thead").each(function(){
var opt=$.parser.parseOptions(this,[{frozen:"boolean"}]);
$(this).find("tr").each(function(){
var _53=[];
$(this).find("th").each(function(){
var th=$(this);
var col=$.extend({},$.parser.parseOptions(this,["id","field","align","halign","order","width",{sortable:"boolean",checkbox:"boolean",resizable:"boolean",fixed:"boolean"},{rowspan:"number",colspan:"number"}]),{title:(th.html()||undefined),hidden:(th.attr("hidden")?true:undefined),formatter:(th.attr("formatter")?eval(th.attr("formatter")):undefined),styler:(th.attr("styler")?eval(th.attr("styler")):undefined),sorter:(th.attr("sorter")?eval(th.attr("sorter")):undefined)});
if(col.width&&String(col.width).indexOf("%")==-1){
col.width=parseInt(col.width);
}
if(th.attr("editor")){
var s=$.trim(th.attr("editor"));
if(s.substr(0,1)=="{"){
col.editor=eval("("+s+")");
}else{
col.editor=s;
}
}
_53.push(col);
});
opt.frozen?_51.push(_53):_52.push(_53);
});
});
return [_51,_52];
};
var _54=$("<div class=\"datagrid-wrap\">"+"<div class=\"datagrid-view\">"+"<div class=\"datagrid-view1\">"+"<div class=\"datagrid-header\">"+"<div class=\"datagrid-header-inner\"></div>"+"</div>"+"<div class=\"datagrid-body\">"+"<div class=\"datagrid-body-inner\"></div>"+"</div>"+"<div class=\"datagrid-footer\">"+"<div class=\"datagrid-footer-inner\"></div>"+"</div>"+"</div>"+"<div class=\"datagrid-view2\">"+"<div class=\"datagrid-header\">"+"<div class=\"datagrid-header-inner\"></div>"+"</div>"+"<div class=\"datagrid-body\"></div>"+"<div class=\"datagrid-footer\">"+"<div class=\"datagrid-footer-inner\"></div>"+"</div>"+"</div>"+"</div>"+"</div>").insertAfter(_4e);
_54.panel({doSize:false,cls:"datagrid"});
$(_4e).addClass("datagrid-f").hide().appendTo(_54.children("div.datagrid-view"));
var cc=_50();
var _55=_54.children("div.datagrid-view");
var _56=_55.children("div.datagrid-view1");
var _57=_55.children("div.datagrid-view2");
return {panel:_54,frozenColumns:cc[0],columns:cc[1],dc:{view:_55,view1:_56,view2:_57,header1:_56.children("div.datagrid-header").children("div.datagrid-header-inner"),header2:_57.children("div.datagrid-header").children("div.datagrid-header-inner"),body1:_56.children("div.datagrid-body").children("div.datagrid-body-inner"),body2:_57.children("div.datagrid-body"),footer1:_56.children("div.datagrid-footer").children("div.datagrid-footer-inner"),footer2:_57.children("div.datagrid-footer").children("div.datagrid-footer-inner")}};
};
function _58(_59){
var _5a=$.data(_59,"datagrid");
var _5b=_5a.options;
var dc=_5a.dc;
var _5c=_5a.panel;
_5a.ss=$(_59).datagrid("createStyleSheet");
_5c.panel($.extend({},_5b,{id:null,doSize:false,onResize:function(_5d,_5e){
if($.data(_59,"datagrid")){
_20(_59);
$(_59).datagrid("fitColumns");
_5b.onResize.call(_5c,_5d,_5e);
}
},onExpand:function(){
if($.data(_59,"datagrid")){
$(_59).datagrid("fixRowHeight").datagrid("fitColumns");
_5b.onExpand.call(_5c);
}
}}));
_5a.rowIdPrefix="datagrid-row-r"+(++_1);
_5a.cellClassPrefix="datagrid-cell-c"+_1;
_5f(dc.header1,_5b.frozenColumns,true);
_5f(dc.header2,_5b.columns,false);
_60();
dc.header1.add(dc.header2).css("display",_5b.showHeader?"block":"none");
dc.footer1.add(dc.footer2).css("display",_5b.showFooter?"block":"none");
if(_5b.toolbar){
if($.isArray(_5b.toolbar)){
$("div.datagrid-toolbar",_5c).remove();
var tb=$("<div class=\"datagrid-toolbar\"><table cellspacing=\"0\" cellpadding=\"0\"><tr></tr></table></div>").prependTo(_5c);
var tr=tb.find("tr");
for(var i=0;i<_5b.toolbar.length;i++){
var btn=_5b.toolbar[i];
if(btn=="-"){
$("<td><div class=\"datagrid-btn-separator\"></div></td>").appendTo(tr);
}else{
var td=$("<td></td>").appendTo(tr);
var _61=$("<a href=\"javascript:;\"></a>").appendTo(td);
_61[0].onclick=eval(btn.handler||function(){
});
_61.linkbutton($.extend({},btn,{plain:true}));
}
}
}else{
$(_5b.toolbar).addClass("datagrid-toolbar").prependTo(_5c);
$(_5b.toolbar).show();
}
}else{
$("div.datagrid-toolbar",_5c).remove();
}
$("div.datagrid-pager",_5c).remove();
if(_5b.pagination){
var _62=$("<div class=\"datagrid-pager\"></div>");
if(_5b.pagePosition=="bottom"){
_62.appendTo(_5c);
}else{
if(_5b.pagePosition=="top"){
_62.addClass("datagrid-pager-top").prependTo(_5c);
}else{
var _63=$("<div class=\"datagrid-pager datagrid-pager-top\"></div>").prependTo(_5c);
_62.appendTo(_5c);
_62=_62.add(_63);
}
}
_62.pagination({total:0,pageNumber:_5b.pageNumber,pageSize:_5b.pageSize,pageList:_5b.pageList,onSelectPage:function(_64,_65){
_5b.pageNumber=_64||1;
_5b.pageSize=_65;
_62.pagination("refresh",{pageNumber:_64,pageSize:_65});
_bf(_59);
}});
_5b.pageSize=_62.pagination("options").pageSize;
}
function _5f(_66,_67,_68){
if(!_67){
return;
}
$(_66).show();
$(_66).empty();
var tmp=$("<div class=\"datagrid-cell\" style=\"position:absolute;left:-99999px\"></div>").appendTo("body");
tmp._outerWidth(99);
var _69=100-parseInt(tmp[0].style.width);
tmp.remove();
var _6a=[];
var _6b=[];
var _6c=[];
if(_5b.sortName){
_6a=_5b.sortName.split(",");
_6b=_5b.sortOrder.split(",");
}
var t=$("<table class=\"datagrid-htable\" border=\"0\" cellspacing=\"0\" cellpadding=\"0\"><tbody></tbody></table>").appendTo(_66);
for(var i=0;i<_67.length;i++){
var tr=$("<tr class=\"datagrid-header-row\"></tr>").appendTo($("tbody",t));
var _6d=_67[i];
for(var j=0;j<_6d.length;j++){
var col=_6d[j];
var _6e="";
if(col.rowspan){
_6e+="rowspan=\""+col.rowspan+"\" ";
}
if(col.colspan){
_6e+="colspan=\""+col.colspan+"\" ";
if(!col.id){
col.id=["datagrid-td-group"+_1,i,j].join("-");
}
}
if(col.id){
_6e+="id=\""+col.id+"\"";
}
var td=$("<td "+_6e+"></td>").appendTo(tr);
if(col.checkbox){
td.attr("field",col.field);
$("<div class=\"datagrid-header-check\"></div>").html("<input type=\"checkbox\"/>").appendTo(td);
}else{
if(col.field){
td.attr("field",col.field);
td.append("<div class=\"datagrid-cell\"><span></span><span class=\"datagrid-sort-icon\"></span></div>");
td.find("span:first").html(col.title);
var _6f=td.find("div.datagrid-cell");
var pos=_2(_6a,col.field);
if(pos>=0){
_6f.addClass("datagrid-sort-"+_6b[pos]);
}
if(col.sortable){
_6f.addClass("datagrid-sort");
}
if(col.resizable==false){
_6f.attr("resizable","false");
}
if(col.width){
var _70=$.parser.parseValue("width",col.width,dc.view,_5b.scrollbarSize+(_5b.rownumbers?_5b.rownumberWidth:0));
col.deltaWidth=_69;
col.boxWidth=_70-_69;
}else{
col.auto=true;
}
_6f.css("text-align",(col.halign||col.align||""));
col.cellClass=_5a.cellClassPrefix+"-"+col.field.replace(/[\.|\s]/g,"-");
_6f.addClass(col.cellClass);
}else{
$("<div class=\"datagrid-cell-group\"></div>").html(col.title).appendTo(td);
}
}
if(col.hidden){
td.hide();
_6c.push(col.field);
}
}
}
if(_68&&_5b.rownumbers){
var td=$("<td rowspan=\""+_5b.frozenColumns.length+"\"><div class=\"datagrid-header-rownumber\"></div></td>");
if($("tr",t).length==0){
td.wrap("<tr class=\"datagrid-header-row\"></tr>").parent().appendTo($("tbody",t));
}else{
td.prependTo($("tr:first",t));
}
}
for(var i=0;i<_6c.length;i++){
_c1(_59,_6c[i],-1);
}
};
function _60(){
var _71=[[".datagrid-header-rownumber",(_5b.rownumberWidth-1)+"px"],[".datagrid-cell-rownumber",(_5b.rownumberWidth-1)+"px"]];
var _72=_73(_59,true).concat(_73(_59));
for(var i=0;i<_72.length;i++){
var col=_74(_59,_72[i]);
if(col&&!col.checkbox){
_71.push(["."+col.cellClass,col.boxWidth?col.boxWidth+"px":"auto"]);
}
}
_5a.ss.add(_71);
_5a.ss.dirty(_5a.cellSelectorPrefix);
_5a.cellSelectorPrefix="."+_5a.cellClassPrefix;
};
};
function _75(_76){
var _77=$.data(_76,"datagrid");
var _78=_77.panel;
var _79=_77.options;
var dc=_77.dc;
var _7a=dc.header1.add(dc.header2);
_7a.unbind(".datagrid");
for(var _7b in _79.headerEvents){
_7a.bind(_7b+".datagrid",_79.headerEvents[_7b]);
}
var _7c=_7a.find("div.datagrid-cell");
var _7d=_79.resizeHandle=="right"?"e":(_79.resizeHandle=="left"?"w":"e,w");
_7c.each(function(){
$(this).resizable({handles:_7d,edge:_79.resizeEdge,disabled:($(this).attr("resizable")?$(this).attr("resizable")=="false":false),minWidth:25,onStartResize:function(e){
_77.resizing=true;
_7a.css("cursor",$("body").css("cursor"));
if(!_77.proxy){
_77.proxy=$("<div class=\"datagrid-resize-proxy\"></div>").appendTo(dc.view);
}
if(e.data.dir=="e"){
e.data.deltaEdge=$(this)._outerWidth()-(e.pageX-$(this).offset().left);
}else{
e.data.deltaEdge=$(this).offset().left-e.pageX-1;
}
_77.proxy.css({left:e.pageX-$(_78).offset().left-1+e.data.deltaEdge,display:"none"});
setTimeout(function(){
if(_77.proxy){
_77.proxy.show();
}
},500);
},onResize:function(e){
_77.proxy.css({left:e.pageX-$(_78).offset().left-1+e.data.deltaEdge,display:"block"});
return false;
},onStopResize:function(e){
_7a.css("cursor","");
$(this).css("height","");
var _7e=$(this).parent().attr("field");
var col=_74(_76,_7e);
col.width=$(this)._outerWidth()+1;
col.boxWidth=col.width-col.deltaWidth;
col.auto=undefined;
$(this).css("width","");
$(_76).datagrid("fixColumnSize",_7e);
_77.proxy.remove();
_77.proxy=null;
if($(this).parents("div:first.datagrid-header").parent().hasClass("datagrid-view1")){
_20(_76);
}
$(_76).datagrid("fitColumns");
_79.onResizeColumn.call(_76,_7e,col.width);
setTimeout(function(){
_77.resizing=false;
},0);
}});
});
var bb=dc.body1.add(dc.body2);
bb.unbind();
for(var _7b in _79.rowEvents){
bb.bind(_7b,_79.rowEvents[_7b]);
}
dc.body1.bind("mousewheel DOMMouseScroll",function(e){
e.preventDefault();
var e1=e.originalEvent||window.event;
var _7f=e1.wheelDelta||e1.detail*(-1);
if("deltaY" in e1){
_7f=e1.deltaY*-1;
}
var dg=$(e.target).closest("div.datagrid-view").children(".datagrid-f");
var dc=dg.data("datagrid").dc;
dc.body2.scrollTop(dc.body2.scrollTop()-_7f);
});
dc.body2.bind("scroll",function(){
var b1=dc.view1.children("div.datagrid-body");
b1.scrollTop($(this).scrollTop());
var c1=dc.body1.children(":first");
var c2=dc.body2.children(":first");
if(c1.length&&c2.length){
var _80=c1.offset().top;
var _81=c2.offset().top;
if(_80!=_81){
b1.scrollTop(b1.scrollTop()+_80-_81);
}
}
dc.view2.children("div.datagrid-header,div.datagrid-footer")._scrollLeft($(this)._scrollLeft());
dc.body2.children("table.datagrid-btable-frozen").css("left",-$(this)._scrollLeft());
});
};
function _82(_83){
return function(e){
var td=$(e.target).closest("td[field]");
if(td.length){
var _84=_85(td);
if(!$(_84).data("datagrid").resizing&&_83){
td.addClass("datagrid-header-over");
}else{
td.removeClass("datagrid-header-over");
}
}
};
};
function _86(e){
var _87=_85(e.target);
var _88=$(_87).datagrid("options");
var ck=$(e.target).closest("input[type=checkbox]");
if(ck.length){
if(_88.singleSelect&&_88.selectOnCheck){
return false;
}
if(ck.is(":checked")){
_89(_87);
}else{
_8a(_87);
}
e.stopPropagation();
}else{
var _8b=$(e.target).closest(".datagrid-cell");
if(_8b.length){
var p1=_8b.offset().left+5;
var p2=_8b.offset().left+_8b._outerWidth()-5;
if(e.pageX<p2&&e.pageX>p1){
_8c(_87,_8b.parent().attr("field"));
}
}
}
};
function _8d(e){
var _8e=_85(e.target);
var _8f=$(_8e).datagrid("options");
var _90=$(e.target).closest(".datagrid-cell");
if(_90.length){
var p1=_90.offset().left+5;
var p2=_90.offset().left+_90._outerWidth()-5;
var _91=_8f.resizeHandle=="right"?(e.pageX>p2):(_8f.resizeHandle=="left"?(e.pageX<p1):(e.pageX<p1||e.pageX>p2));
if(_91){
var _92=_90.parent().attr("field");
var col=_74(_8e,_92);
if(col.resizable==false){
return;
}
$(_8e).datagrid("autoSizeColumn",_92);
col.auto=false;
}
}
};
function _93(e){
var _94=_85(e.target);
var _95=$(_94).datagrid("options");
var td=$(e.target).closest("td[field]");
_95.onHeaderContextMenu.call(_94,e,td.attr("field"));
};
function _96(_97){
return function(e){
var tr=_98(e.target);
if(!tr){
return;
}
var _99=_85(tr);
if($.data(_99,"datagrid").resizing){
return;
}
var _9a=_9b(tr);
if(_97){
_9c(_99,_9a);
}else{
var _9d=$.data(_99,"datagrid").options;
_9d.finder.getTr(_99,_9a).removeClass("datagrid-row-over");
}
};
};
function _9e(e){
var tr=_98(e.target);
if(!tr){
return;
}
var _9f=_85(tr);
var _a0=$.data(_9f,"datagrid").options;
var _a1=_9b(tr);
var tt=$(e.target);
if(tt.parent().hasClass("datagrid-cell-check")){
if(_a0.singleSelect&&_a0.selectOnCheck){
tt._propAttr("checked",!tt.is(":checked"));
_a2(_9f,_a1);
}else{
if(tt.is(":checked")){
tt._propAttr("checked",false);
_a2(_9f,_a1);
}else{
tt._propAttr("checked",true);
_a3(_9f,_a1);
}
}
}else{
var row=_a0.finder.getRow(_9f,_a1);
var td=tt.closest("td[field]",tr);
if(td.length){
var _a4=td.attr("field");
_a0.onClickCell.call(_9f,_a1,_a4,row[_a4]);
}
if(_a0.singleSelect==true){
_a5(_9f,_a1);
}else{
if(_a0.ctrlSelect){
if(e.metaKey||e.ctrlKey){
if(tr.hasClass("datagrid-row-selected")){
_a6(_9f,_a1);
}else{
_a5(_9f,_a1);
}
}else{
if(e.shiftKey){
$(_9f).datagrid("clearSelections");
var _a7=Math.min(_a0.lastSelectedIndex||0,_a1);
var _a8=Math.max(_a0.lastSelectedIndex||0,_a1);
for(var i=_a7;i<=_a8;i++){
_a5(_9f,i);
}
}else{
$(_9f).datagrid("clearSelections");
_a5(_9f,_a1);
_a0.lastSelectedIndex=_a1;
}
}
}else{
if(tr.hasClass("datagrid-row-selected")){
_a6(_9f,_a1);
}else{
_a5(_9f,_a1);
}
}
}
_a0.onClickRow.apply(_9f,_5(_9f,[_a1,row]));
}
};
function _a9(e){
var tr=_98(e.target);
if(!tr){
return;
}
var _aa=_85(tr);
var _ab=$.data(_aa,"datagrid").options;
var _ac=_9b(tr);
var row=_ab.finder.getRow(_aa,_ac);
var td=$(e.target).closest("td[field]",tr);
if(td.length){
var _ad=td.attr("field");
_ab.onDblClickCell.call(_aa,_ac,_ad,row[_ad]);
}
_ab.onDblClickRow.apply(_aa,_5(_aa,[_ac,row]));
};
function _ae(e){
var tr=_98(e.target);
if(tr){
var _af=_85(tr);
var _b0=$.data(_af,"datagrid").options;
var _b1=_9b(tr);
var row=_b0.finder.getRow(_af,_b1);
_b0.onRowContextMenu.call(_af,e,_b1,row);
}else{
var _b2=_98(e.target,".datagrid-body");
if(_b2){
var _af=_85(_b2);
var _b0=$.data(_af,"datagrid").options;
_b0.onRowContextMenu.call(_af,e,-1,null);
}
}
};
function _85(t){
return $(t).closest("div.datagrid-view").children(".datagrid-f")[0];
};
function _98(t,_b3){
var tr=$(t).closest(_b3||"tr.datagrid-row");
if(tr.length&&tr.parent().length){
return tr;
}else{
return undefined;
}
};
function _9b(tr){
if(tr.attr("datagrid-row-index")){
return parseInt(tr.attr("datagrid-row-index"));
}else{
return tr.attr("node-id");
}
};
function _8c(_b4,_b5){
var _b6=$.data(_b4,"datagrid");
var _b7=_b6.options;
_b5=_b5||{};
var _b8={sortName:_b7.sortName,sortOrder:_b7.sortOrder};
if(typeof _b5=="object"){
$.extend(_b8,_b5);
}
var _b9=[];
var _ba=[];
if(_b8.sortName){
_b9=_b8.sortName.split(",");
_ba=_b8.sortOrder.split(",");
}
if(typeof _b5=="string"){
var _bb=_b5;
var col=_74(_b4,_bb);
if(!col.sortable||_b6.resizing){
return;
}
var _bc=col.order||"asc";
var pos=_2(_b9,_bb);
if(pos>=0){
var _bd=_ba[pos]=="asc"?"desc":"asc";
if(_b7.multiSort&&_bd==_bc){
_b9.splice(pos,1);
_ba.splice(pos,1);
}else{
_ba[pos]=_bd;
}
}else{
if(_b7.multiSort){
_b9.push(_bb);
_ba.push(_bc);
}else{
_b9=[_bb];
_ba=[_bc];
}
}
_b8.sortName=_b9.join(",");
_b8.sortOrder=_ba.join(",");
}
if(_b7.onBeforeSortColumn.call(_b4,_b8.sortName,_b8.sortOrder)==false){
return;
}
$.extend(_b7,_b8);
var dc=_b6.dc;
var _be=dc.header1.add(dc.header2);
_be.find("div.datagrid-cell").removeClass("datagrid-sort-asc datagrid-sort-desc");
for(var i=0;i<_b9.length;i++){
var col=_74(_b4,_b9[i]);
_be.find("div."+col.cellClass).addClass("datagrid-sort-"+_ba[i]);
}
if(_b7.remoteSort){
_bf(_b4);
}else{
_c0(_b4,$(_b4).datagrid("getData"));
}
_b7.onSortColumn.call(_b4,_b7.sortName,_b7.sortOrder);
};
function _c1(_c2,_c3,_c4){
_c5(true);
_c5(false);
function _c5(_c6){
var aa=_c7(_c2,_c6);
if(aa.length){
var _c8=aa[aa.length-1];
var _c9=_2(_c8,_c3);
if(_c9>=0){
for(var _ca=0;_ca<aa.length-1;_ca++){
var td=$("#"+aa[_ca][_c9]);
var _cb=parseInt(td.attr("colspan")||1)+(_c4||0);
td.attr("colspan",_cb);
if(_cb){
td.show();
}else{
td.hide();
}
}
}
}
};
};
function _cc(_cd){
var _ce=$.data(_cd,"datagrid");
var _cf=_ce.options;
var dc=_ce.dc;
var _d0=dc.view2.children("div.datagrid-header");
dc.body2.css("overflow-x","");
_d1();
_d2();
_d3();
_d1(true);
if(_d0.width()>=_d0.find("table").width()){
dc.body2.css("overflow-x","hidden");
}
function _d3(){
if(!_cf.fitColumns){
return;
}
if(!_ce.leftWidth){
_ce.leftWidth=0;
}
var _d4=0;
var cc=[];
var _d5=_73(_cd,false);
for(var i=0;i<_d5.length;i++){
var col=_74(_cd,_d5[i]);
if(_d6(col)){
_d4+=col.width;
cc.push({field:col.field,col:col,addingWidth:0});
}
}
if(!_d4){
return;
}
cc[cc.length-1].addingWidth-=_ce.leftWidth;
var _d7=_d0.children("div.datagrid-header-inner").show();
var _d8=_d0.width()-_d0.find("table").width()-_cf.scrollbarSize+_ce.leftWidth;
var _d9=_d8/_d4;
if(!_cf.showHeader){
_d7.hide();
}
for(var i=0;i<cc.length;i++){
var c=cc[i];
var _da=parseInt(c.col.width*_d9);
c.addingWidth+=_da;
_d8-=_da;
}
cc[cc.length-1].addingWidth+=_d8;
for(var i=0;i<cc.length;i++){
var c=cc[i];
if(c.col.boxWidth+c.addingWidth>0){
c.col.boxWidth+=c.addingWidth;
c.col.width+=c.addingWidth;
}
}
_ce.leftWidth=_d8;
$(_cd).datagrid("fixColumnSize");
};
function _d2(){
var _db=false;
var _dc=_73(_cd,true).concat(_73(_cd,false));
$.map(_dc,function(_dd){
var col=_74(_cd,_dd);
if(String(col.width||"").indexOf("%")>=0){
var _de=$.parser.parseValue("width",col.width,dc.view,_cf.scrollbarSize+(_cf.rownumbers?_cf.rownumberWidth:0))-col.deltaWidth;
if(_de>0){
col.boxWidth=_de;
_db=true;
}
}
});
if(_db){
$(_cd).datagrid("fixColumnSize");
}
};
function _d1(fit){
var _df=dc.header1.add(dc.header2).find(".datagrid-cell-group");
if(_df.length){
_df.each(function(){
$(this)._outerWidth(fit?$(this).parent().width():10);
});
if(fit){
_20(_cd);
}
}
};
function _d6(col){
if(String(col.width||"").indexOf("%")>=0){
return false;
}
if(!col.hidden&&!col.checkbox&&!col.auto&&!col.fixed){
return true;
}
};
};
function _e0(_e1,_e2){
var _e3=$.data(_e1,"datagrid");
var _e4=_e3.options;
var dc=_e3.dc;
var tmp=$("<div class=\"datagrid-cell\" style=\"position:absolute;left:-9999px\"></div>").appendTo("body");
if(_e2){
_1a(_e2);
$(_e1).datagrid("fitColumns");
}else{
var _e5=false;
var _e6=_73(_e1,true).concat(_73(_e1,false));
for(var i=0;i<_e6.length;i++){
var _e2=_e6[i];
var col=_74(_e1,_e2);
if(col.auto){
_1a(_e2);
_e5=true;
}
}
if(_e5){
$(_e1).datagrid("fitColumns");
}
}
tmp.remove();
function _1a(_e7){
var _e8=dc.view.find("div.datagrid-header td[field=\""+_e7+"\"] div.datagrid-cell");
_e8.css("width","");
var col=$(_e1).datagrid("getColumnOption",_e7);
col.width=undefined;
col.boxWidth=undefined;
col.auto=true;
$(_e1).datagrid("fixColumnSize",_e7);
var _e9=Math.max(_ea("header"),_ea("allbody"),_ea("allfooter"))+1;
_e8._outerWidth(_e9-1);
col.width=_e9;
col.boxWidth=parseInt(_e8[0].style.width);
col.deltaWidth=_e9-col.boxWidth;
_e8.css("width","");
$(_e1).datagrid("fixColumnSize",_e7);
_e4.onResizeColumn.call(_e1,_e7,col.width);
function _ea(_eb){
var _ec=0;
if(_eb=="header"){
_ec=_ed(_e8);
}else{
_e4.finder.getTr(_e1,0,_eb).find("td[field=\""+_e7+"\"] div.datagrid-cell").each(function(){
var w=_ed($(this));
if(_ec<w){
_ec=w;
}
});
}
return _ec;
function _ed(_ee){
return _ee.is(":visible")?_ee._outerWidth():tmp.html(_ee.html())._outerWidth();
};
};
};
};
function _ef(_f0,_f1){
var _f2=$.data(_f0,"datagrid");
var _f3=_f2.options;
var dc=_f2.dc;
var _f4=dc.view.find("table.datagrid-btable,table.datagrid-ftable");
_f4.css("table-layout","fixed");
if(_f1){
fix(_f1);
}else{
var ff=_73(_f0,true).concat(_73(_f0,false));
for(var i=0;i<ff.length;i++){
fix(ff[i]);
}
}
_f4.css("table-layout","");
_f5(_f0);
_34(_f0);
_f6(_f0);
function fix(_f7){
var col=_74(_f0,_f7);
if(col.cellClass){
_f2.ss.set("."+col.cellClass,col.boxWidth?col.boxWidth+"px":"auto");
}
};
};
function _f5(_f8,tds){
var dc=$.data(_f8,"datagrid").dc;
tds=tds||dc.view.find("td.datagrid-td-merged");
tds.each(function(){
var td=$(this);
var _f9=td.attr("colspan")||1;
if(_f9>1){
var col=_74(_f8,td.attr("field"));
var _fa=col.boxWidth+col.deltaWidth-1;
for(var i=1;i<_f9;i++){
td=td.next();
col=_74(_f8,td.attr("field"));
_fa+=col.boxWidth+col.deltaWidth;
}
$(this).children("div.datagrid-cell")._outerWidth(_fa);
}
});
};
function _f6(_fb){
var dc=$.data(_fb,"datagrid").dc;
dc.view.find("div.datagrid-editable").each(function(){
var _fc=$(this);
var _fd=_fc.parent().attr("field");
var col=$(_fb).datagrid("getColumnOption",_fd);
_fc._outerWidth(col.boxWidth+col.deltaWidth-1);
var ed=$.data(this,"datagrid.editor");
if(ed.actions.resize){
ed.actions.resize(ed.target,_fc.width());
}
});
};
function _74(_fe,_ff){
function find(_100){
if(_100){
for(var i=0;i<_100.length;i++){
var cc=_100[i];
for(var j=0;j<cc.length;j++){
var c=cc[j];
if(c.field==_ff){
return c;
}
}
}
}
return null;
};
var opts=$.data(_fe,"datagrid").options;
var col=find(opts.columns);
if(!col){
col=find(opts.frozenColumns);
}
return col;
};
function _c7(_101,_102){
var opts=$.data(_101,"datagrid").options;
var _103=_102?opts.frozenColumns:opts.columns;
var aa=[];
var _104=_105();
for(var i=0;i<_103.length;i++){
aa[i]=new Array(_104);
}
for(var _106=0;_106<_103.length;_106++){
$.map(_103[_106],function(col){
var _107=_108(aa[_106]);
if(_107>=0){
var _109=col.field||col.id||"";
for(var c=0;c<(col.colspan||1);c++){
for(var r=0;r<(col.rowspan||1);r++){
aa[_106+r][_107]=_109;
}
_107++;
}
}
});
}
return aa;
function _105(){
var _10a=0;
$.map(_103[0]||[],function(col){
_10a+=col.colspan||1;
});
return _10a;
};
function _108(a){
for(var i=0;i<a.length;i++){
if(a[i]==undefined){
return i;
}
}
return -1;
};
};
function _73(_10b,_10c){
var aa=_c7(_10b,_10c);
return aa.length?aa[aa.length-1]:aa;
};
function _c0(_10d,data){
var _10e=$.data(_10d,"datagrid");
var opts=_10e.options;
var dc=_10e.dc;
data=opts.loadFilter.call(_10d,data);
if($.isArray(data)){
data={total:data.length,rows:data};
}
data.total=parseInt(data.total);
_10e.data=data;
if(data.footer){
_10e.footer=data.footer;
}
if(!opts.remoteSort&&opts.sortName){
var _10f=opts.sortName.split(",");
var _110=opts.sortOrder.split(",");
data.rows.sort(function(r1,r2){
var r=0;
for(var i=0;i<_10f.length;i++){
var sn=_10f[i];
var so=_110[i];
var col=_74(_10d,sn);
var _111=col.sorter||function(a,b){
return a==b?0:(a>b?1:-1);
};
r=_111(r1[sn],r2[sn])*(so=="asc"?1:-1);
if(r!=0){
return r;
}
}
return r;
});
}
if(opts.view.onBeforeRender){
opts.view.onBeforeRender.call(opts.view,_10d,data.rows);
}
opts.view.render.call(opts.view,_10d,dc.body2,false);
opts.view.render.call(opts.view,_10d,dc.body1,true);
if(opts.showFooter){
opts.view.renderFooter.call(opts.view,_10d,dc.footer2,false);
opts.view.renderFooter.call(opts.view,_10d,dc.footer1,true);
}
if(opts.view.onAfterRender){
opts.view.onAfterRender.call(opts.view,_10d);
}
_10e.ss.clean();
var _112=$(_10d).datagrid("getPager");
if(_112.length){
var _113=_112.pagination("options");
if(_113.total!=data.total){
_112.pagination("refresh",{pageNumber:opts.pageNumber,total:data.total});
if(opts.pageNumber!=_113.pageNumber&&_113.pageNumber>0){
opts.pageNumber=_113.pageNumber;
_bf(_10d);
}
}
}
_34(_10d);
dc.body2.triggerHandler("scroll");
$(_10d).datagrid("setSelectionState");
$(_10d).datagrid("autoSizeColumn");
opts.onLoadSuccess.call(_10d,data);
};
function _114(_115){
var _116=$.data(_115,"datagrid");
var opts=_116.options;
var dc=_116.dc;
dc.header1.add(dc.header2).find("input[type=checkbox]")._propAttr("checked",false);
if(opts.idField){
var _117=$.data(_115,"treegrid")?true:false;
var _118=opts.onSelect;
var _119=opts.onCheck;
opts.onSelect=opts.onCheck=function(){
};
var rows=opts.finder.getRows(_115);
for(var i=0;i<rows.length;i++){
var row=rows[i];
var _11a=_117?row[opts.idField]:$(_115).datagrid("getRowIndex",row[opts.idField]);
if(_11b(_116.selectedRows,row)){
_a5(_115,_11a,true,true);
}
if(_11b(_116.checkedRows,row)){
_a2(_115,_11a,true);
}
}
opts.onSelect=_118;
opts.onCheck=_119;
}
function _11b(a,r){
for(var i=0;i<a.length;i++){
if(a[i][opts.idField]==r[opts.idField]){
a[i]=r;
return true;
}
}
return false;
};
};
function _11c(_11d,row){
var _11e=$.data(_11d,"datagrid");
var opts=_11e.options;
var rows=_11e.data.rows;
if(typeof row=="object"){
return _2(rows,row);
}else{
for(var i=0;i<rows.length;i++){
if(rows[i][opts.idField]==row){
return i;
}
}
return -1;
}
};
function _11f(_120){
var _121=$.data(_120,"datagrid");
var opts=_121.options;
var data=_121.data;
if(opts.idField){
return _121.selectedRows;
}else{
var rows=[];
opts.finder.getTr(_120,"","selected",2).each(function(){
rows.push(opts.finder.getRow(_120,$(this)));
});
return rows;
}
};
function _122(_123){
var _124=$.data(_123,"datagrid");
var opts=_124.options;
if(opts.idField){
return _124.checkedRows;
}else{
var rows=[];
opts.finder.getTr(_123,"","checked",2).each(function(){
rows.push(opts.finder.getRow(_123,$(this)));
});
return rows;
}
};
function _125(_126,_127){
var _128=$.data(_126,"datagrid");
var dc=_128.dc;
var opts=_128.options;
var tr=opts.finder.getTr(_126,_127);
if(tr.length){
if(tr.closest("table").hasClass("datagrid-btable-frozen")){
return;
}
var _129=dc.view2.children("div.datagrid-header")._outerHeight();
var _12a=dc.body2;
var _12b=opts.scrollbarSize;
if(_12a[0].offsetHeight&&_12a[0].clientHeight&&_12a[0].offsetHeight<=_12a[0].clientHeight){
_12b=0;
}
var _12c=_12a.outerHeight(true)-_12a.outerHeight();
var top=tr.position().top-_129-_12c;
if(top<0){
_12a.scrollTop(_12a.scrollTop()+top);
}else{
if(top+tr._outerHeight()>_12a.height()-_12b){
_12a.scrollTop(_12a.scrollTop()+top+tr._outerHeight()-_12a.height()+_12b);
}
}
}
};
function _9c(_12d,_12e){
var _12f=$.data(_12d,"datagrid");
var opts=_12f.options;
opts.finder.getTr(_12d,_12f.highlightIndex).removeClass("datagrid-row-over");
opts.finder.getTr(_12d,_12e).addClass("datagrid-row-over");
_12f.highlightIndex=_12e;
};
function _a5(_130,_131,_132,_133){
var _134=$.data(_130,"datagrid");
var opts=_134.options;
var row=opts.finder.getRow(_130,_131);
if(!row){
return;
}
if(opts.onBeforeSelect.apply(_130,_5(_130,[_131,row]))==false){
return;
}
if(opts.singleSelect){
_135(_130,true);
_134.selectedRows=[];
}
if(!_132&&opts.checkOnSelect){
_a2(_130,_131,true);
}
if(opts.idField){
_4(_134.selectedRows,opts.idField,row);
}
opts.finder.getTr(_130,_131).addClass("datagrid-row-selected");
opts.onSelect.apply(_130,_5(_130,[_131,row]));
if(!_133&&opts.scrollOnSelect){
_125(_130,_131);
}
};
function _a6(_136,_137,_138){
var _139=$.data(_136,"datagrid");
var dc=_139.dc;
var opts=_139.options;
var row=opts.finder.getRow(_136,_137);
if(!row){
return;
}
if(opts.onBeforeUnselect.apply(_136,_5(_136,[_137,row]))==false){
return;
}
if(!_138&&opts.checkOnSelect){
_a3(_136,_137,true);
}
opts.finder.getTr(_136,_137).removeClass("datagrid-row-selected");
if(opts.idField){
_3(_139.selectedRows,opts.idField,row[opts.idField]);
}
opts.onUnselect.apply(_136,_5(_136,[_137,row]));
};
function _13a(_13b,_13c){
var _13d=$.data(_13b,"datagrid");
var opts=_13d.options;
var rows=opts.finder.getRows(_13b);
var _13e=$.data(_13b,"datagrid").selectedRows;
if(!_13c&&opts.checkOnSelect){
_89(_13b,true);
}
opts.finder.getTr(_13b,"","allbody").addClass("datagrid-row-selected");
if(opts.idField){
for(var _13f=0;_13f<rows.length;_13f++){
_4(_13e,opts.idField,rows[_13f]);
}
}
opts.onSelectAll.call(_13b,rows);
};
function _135(_140,_141){
var _142=$.data(_140,"datagrid");
var opts=_142.options;
var rows=opts.finder.getRows(_140);
var _143=$.data(_140,"datagrid").selectedRows;
if(!_141&&opts.checkOnSelect){
_8a(_140,true);
}
opts.finder.getTr(_140,"","selected").removeClass("datagrid-row-selected");
if(opts.idField){
for(var _144=0;_144<rows.length;_144++){
_3(_143,opts.idField,rows[_144][opts.idField]);
}
}
opts.onUnselectAll.call(_140,rows);
};
function _a2(_145,_146,_147){
var _148=$.data(_145,"datagrid");
var opts=_148.options;
var row=opts.finder.getRow(_145,_146);
if(!row){
return;
}
if(opts.onBeforeCheck.apply(_145,_5(_145,[_146,row]))==false){
return;
}
if(opts.singleSelect&&opts.selectOnCheck){
_8a(_145,true);
_148.checkedRows=[];
}
if(!_147&&opts.selectOnCheck){
_a5(_145,_146,true);
}
var tr=opts.finder.getTr(_145,_146).addClass("datagrid-row-checked");
tr.find("div.datagrid-cell-check input[type=checkbox]")._propAttr("checked",true);
tr=opts.finder.getTr(_145,"","checked",2);
if(tr.length==opts.finder.getRows(_145).length){
var dc=_148.dc;
dc.header1.add(dc.header2).find("input[type=checkbox]")._propAttr("checked",true);
}
if(opts.idField){
_4(_148.checkedRows,opts.idField,row);
}
opts.onCheck.apply(_145,_5(_145,[_146,row]));
};
function _a3(_149,_14a,_14b){
var _14c=$.data(_149,"datagrid");
var opts=_14c.options;
var row=opts.finder.getRow(_149,_14a);
if(!row){
return;
}
if(opts.onBeforeUncheck.apply(_149,_5(_149,[_14a,row]))==false){
return;
}
if(!_14b&&opts.selectOnCheck){
_a6(_149,_14a,true);
}
var tr=opts.finder.getTr(_149,_14a).removeClass("datagrid-row-checked");
tr.find("div.datagrid-cell-check input[type=checkbox]")._propAttr("checked",false);
var dc=_14c.dc;
var _14d=dc.header1.add(dc.header2);
_14d.find("input[type=checkbox]")._propAttr("checked",false);
if(opts.idField){
_3(_14c.checkedRows,opts.idField,row[opts.idField]);
}
opts.onUncheck.apply(_149,_5(_149,[_14a,row]));
};
function _89(_14e,_14f){
var _150=$.data(_14e,"datagrid");
var opts=_150.options;
var rows=opts.finder.getRows(_14e);
if(!_14f&&opts.selectOnCheck){
_13a(_14e,true);
}
var dc=_150.dc;
var hck=dc.header1.add(dc.header2).find("input[type=checkbox]");
var bck=opts.finder.getTr(_14e,"","allbody").addClass("datagrid-row-checked").find("div.datagrid-cell-check input[type=checkbox]");
hck.add(bck)._propAttr("checked",true);
if(opts.idField){
for(var i=0;i<rows.length;i++){
_4(_150.checkedRows,opts.idField,rows[i]);
}
}
opts.onCheckAll.call(_14e,rows);
};
function _8a(_151,_152){
var _153=$.data(_151,"datagrid");
var opts=_153.options;
var rows=opts.finder.getRows(_151);
if(!_152&&opts.selectOnCheck){
_135(_151,true);
}
var dc=_153.dc;
var hck=dc.header1.add(dc.header2).find("input[type=checkbox]");
var bck=opts.finder.getTr(_151,"","checked").removeClass("datagrid-row-checked").find("div.datagrid-cell-check input[type=checkbox]");
hck.add(bck)._propAttr("checked",false);
if(opts.idField){
for(var i=0;i<rows.length;i++){
_3(_153.checkedRows,opts.idField,rows[i][opts.idField]);
}
}
opts.onUncheckAll.call(_151,rows);
};
function _154(_155,_156){
var opts=$.data(_155,"datagrid").options;
var tr=opts.finder.getTr(_155,_156);
var row=opts.finder.getRow(_155,_156);
if(tr.hasClass("datagrid-row-editing")){
return;
}
if(opts.onBeforeEdit.apply(_155,_5(_155,[_156,row]))==false){
return;
}
tr.addClass("datagrid-row-editing");
_157(_155,_156);
_f6(_155);
tr.find("div.datagrid-editable").each(function(){
var _158=$(this).parent().attr("field");
var ed=$.data(this,"datagrid.editor");
ed.actions.setValue(ed.target,row[_158]);
});
_159(_155,_156);
opts.onBeginEdit.apply(_155,_5(_155,[_156,row]));
};
function _15a(_15b,_15c,_15d){
var _15e=$.data(_15b,"datagrid");
var opts=_15e.options;
var _15f=_15e.updatedRows;
var _160=_15e.insertedRows;
var tr=opts.finder.getTr(_15b,_15c);
var row=opts.finder.getRow(_15b,_15c);
if(!tr.hasClass("datagrid-row-editing")){
return;
}
if(!_15d){
if(!_159(_15b,_15c)){
return;
}
var _161=false;
var _162={};
tr.find("div.datagrid-editable").each(function(){
var _163=$(this).parent().attr("field");
var ed=$.data(this,"datagrid.editor");
var t=$(ed.target);
var _164=t.data("textbox")?t.textbox("textbox"):t;
if(_164.is(":focus")){
_164.triggerHandler("blur");
}
var _165=ed.actions.getValue(ed.target);
if(row[_163]!==_165){
row[_163]=_165;
_161=true;
_162[_163]=_165;
}
});
if(_161){
if(_2(_160,row)==-1){
if(_2(_15f,row)==-1){
_15f.push(row);
}
}
}
opts.onEndEdit.apply(_15b,_5(_15b,[_15c,row,_162]));
}
tr.removeClass("datagrid-row-editing");
_166(_15b,_15c);
$(_15b).datagrid("refreshRow",_15c);
if(!_15d){
opts.onAfterEdit.apply(_15b,_5(_15b,[_15c,row,_162]));
}else{
opts.onCancelEdit.apply(_15b,_5(_15b,[_15c,row]));
}
};
function _167(_168,_169){
var opts=$.data(_168,"datagrid").options;
var tr=opts.finder.getTr(_168,_169);
var _16a=[];
tr.children("td").each(function(){
var cell=$(this).find("div.datagrid-editable");
if(cell.length){
var ed=$.data(cell[0],"datagrid.editor");
_16a.push(ed);
}
});
return _16a;
};
function _16b(_16c,_16d){
var _16e=_167(_16c,_16d.index!=undefined?_16d.index:_16d.id);
for(var i=0;i<_16e.length;i++){
if(_16e[i].field==_16d.field){
return _16e[i];
}
}
return null;
};
function _157(_16f,_170){
var opts=$.data(_16f,"datagrid").options;
var tr=opts.finder.getTr(_16f,_170);
tr.children("td").each(function(){
var cell=$(this).find("div.datagrid-cell");
var _171=$(this).attr("field");
var col=_74(_16f,_171);
if(col&&col.editor){
var _172,_173;
if(typeof col.editor=="string"){
_172=col.editor;
}else{
_172=col.editor.type;
_173=col.editor.options;
}
var _174=opts.editors[_172];
if(_174){
var _175=cell.html();
var _176=cell._outerWidth();
cell.addClass("datagrid-editable");
cell._outerWidth(_176);
cell.html("<table border=\"0\" cellspacing=\"0\" cellpadding=\"1\"><tr><td></td></tr></table>");
cell.children("table").bind("click dblclick contextmenu",function(e){
e.stopPropagation();
});
$.data(cell[0],"datagrid.editor",{actions:_174,target:_174.init(cell.find("td"),$.extend({height:opts.editorHeight},_173)),field:_171,type:_172,oldHtml:_175});
}
}
});
_34(_16f,_170,true);
};
function _166(_177,_178){
var opts=$.data(_177,"datagrid").options;
var tr=opts.finder.getTr(_177,_178);
tr.children("td").each(function(){
var cell=$(this).find("div.datagrid-editable");
if(cell.length){
var ed=$.data(cell[0],"datagrid.editor");
if(ed.actions.destroy){
ed.actions.destroy(ed.target);
}
cell.html(ed.oldHtml);
$.removeData(cell[0],"datagrid.editor");
cell.removeClass("datagrid-editable");
cell.css("width","");
}
});
};
function _159(_179,_17a){
var tr=$.data(_179,"datagrid").options.finder.getTr(_179,_17a);
if(!tr.hasClass("datagrid-row-editing")){
return true;
}
var vbox=tr.find(".validatebox-text");
vbox.validatebox("validate");
vbox.trigger("mouseleave");
var _17b=tr.find(".validatebox-invalid");
return _17b.length==0;
};
function _17c(_17d,_17e){
var _17f=$.data(_17d,"datagrid").insertedRows;
var _180=$.data(_17d,"datagrid").deletedRows;
var _181=$.data(_17d,"datagrid").updatedRows;
if(!_17e){
var rows=[];
rows=rows.concat(_17f);
rows=rows.concat(_180);
rows=rows.concat(_181);
return rows;
}else{
if(_17e=="inserted"){
return _17f;
}else{
if(_17e=="deleted"){
return _180;
}else{
if(_17e=="updated"){
return _181;
}
}
}
}
return [];
};
function _182(_183,_184){
var _185=$.data(_183,"datagrid");
var opts=_185.options;
var data=_185.data;
var _186=_185.insertedRows;
var _187=_185.deletedRows;
$(_183).datagrid("cancelEdit",_184);
var row=opts.finder.getRow(_183,_184);
if(_2(_186,row)>=0){
_3(_186,row);
}else{
_187.push(row);
}
_3(_185.selectedRows,opts.idField,row[opts.idField]);
_3(_185.checkedRows,opts.idField,row[opts.idField]);
opts.view.deleteRow.call(opts.view,_183,_184);
if(opts.height=="auto"){
_34(_183);
}
$(_183).datagrid("getPager").pagination("refresh",{total:data.total});
};
function _188(_189,_18a){
var data=$.data(_189,"datagrid").data;
var view=$.data(_189,"datagrid").options.view;
var _18b=$.data(_189,"datagrid").insertedRows;
view.insertRow.call(view,_189,_18a.index,_18a.row);
_18b.push(_18a.row);
$(_189).datagrid("getPager").pagination("refresh",{total:data.total});
};
function _18c(_18d,row){
var data=$.data(_18d,"datagrid").data;
var view=$.data(_18d,"datagrid").options.view;
var _18e=$.data(_18d,"datagrid").insertedRows;
view.insertRow.call(view,_18d,null,row);
_18e.push(row);
$(_18d).datagrid("getPager").pagination("refresh",{total:data.total});
};
function _18f(_190,_191){
var _192=$.data(_190,"datagrid");
var opts=_192.options;
var row=opts.finder.getRow(_190,_191.index);
var _193=false;
_191.row=_191.row||{};
for(var _194 in _191.row){
if(row[_194]!==_191.row[_194]){
_193=true;
break;
}
}
if(_193){
if(_2(_192.insertedRows,row)==-1){
if(_2(_192.updatedRows,row)==-1){
_192.updatedRows.push(row);
}
}
opts.view.updateRow.call(opts.view,_190,_191.index,_191.row);
}
};
function _195(_196){
var _197=$.data(_196,"datagrid");
var data=_197.data;
var rows=data.rows;
var _198=[];
for(var i=0;i<rows.length;i++){
_198.push($.extend({},rows[i]));
}
_197.originalRows=_198;
_197.updatedRows=[];
_197.insertedRows=[];
_197.deletedRows=[];
};
function _199(_19a){
var data=$.data(_19a,"datagrid").data;
var ok=true;
for(var i=0,len=data.rows.length;i<len;i++){
if(_159(_19a,i)){
$(_19a).datagrid("endEdit",i);
}else{
ok=false;
}
}
if(ok){
_195(_19a);
}
};
function _19b(_19c){
var _19d=$.data(_19c,"datagrid");
var opts=_19d.options;
var _19e=_19d.originalRows;
var _19f=_19d.insertedRows;
var _1a0=_19d.deletedRows;
var _1a1=_19d.selectedRows;
var _1a2=_19d.checkedRows;
var data=_19d.data;
function _1a3(a){
var ids=[];
for(var i=0;i<a.length;i++){
ids.push(a[i][opts.idField]);
}
return ids;
};
function _1a4(ids,_1a5){
for(var i=0;i<ids.length;i++){
var _1a6=_11c(_19c,ids[i]);
if(_1a6>=0){
(_1a5=="s"?_a5:_a2)(_19c,_1a6,true);
}
}
};
for(var i=0;i<data.rows.length;i++){
$(_19c).datagrid("cancelEdit",i);
}
var _1a7=_1a3(_1a1);
var _1a8=_1a3(_1a2);
_1a1.splice(0,_1a1.length);
_1a2.splice(0,_1a2.length);
data.total+=_1a0.length-_19f.length;
data.rows=_19e;
_c0(_19c,data);
_1a4(_1a7,"s");
_1a4(_1a8,"c");
_195(_19c);
};
function _bf(_1a9,_1aa,cb){
var opts=$.data(_1a9,"datagrid").options;
if(_1aa){
opts.queryParams=_1aa;
}
var _1ab=$.extend({},opts.queryParams);
if(opts.pagination){
$.extend(_1ab,{page:opts.pageNumber||1,rows:opts.pageSize});
}
if(opts.sortName){
$.extend(_1ab,{sort:opts.sortName,order:opts.sortOrder});
}
if(opts.onBeforeLoad.call(_1a9,_1ab)==false){
opts.view.setEmptyMsg(_1a9);
return;
}
$(_1a9).datagrid("loading");
var _1ac=opts.loader.call(_1a9,_1ab,function(data){
$(_1a9).datagrid("loaded");
$(_1a9).datagrid("loadData",data);
if(cb){
cb();
}
},function(){
$(_1a9).datagrid("loaded");
opts.onLoadError.apply(_1a9,arguments);
});
if(_1ac==false){
$(_1a9).datagrid("loaded");
opts.view.setEmptyMsg(_1a9);
}
};
function _1ad(_1ae,_1af){
var opts=$.data(_1ae,"datagrid").options;
_1af.type=_1af.type||"body";
_1af.rowspan=_1af.rowspan||1;
_1af.colspan=_1af.colspan||1;
if(_1af.rowspan==1&&_1af.colspan==1){
return;
}
var tr=opts.finder.getTr(_1ae,(_1af.index!=undefined?_1af.index:_1af.id),_1af.type);
if(!tr.length){
return;
}
var td=tr.find("td[field=\""+_1af.field+"\"]");
td.attr("rowspan",_1af.rowspan).attr("colspan",_1af.colspan);
td.addClass("datagrid-td-merged");
_1b0(td.next(),_1af.colspan-1);
for(var i=1;i<_1af.rowspan;i++){
tr=tr.next();
if(!tr.length){
break;
}
_1b0(tr.find("td[field=\""+_1af.field+"\"]"),_1af.colspan);
}
_f5(_1ae,td);
function _1b0(td,_1b1){
for(var i=0;i<_1b1;i++){
td.hide();
td=td.next();
}
};
};
$.fn.datagrid=function(_1b2,_1b3){
if(typeof _1b2=="string"){
return $.fn.datagrid.methods[_1b2](this,_1b3);
}
_1b2=_1b2||{};
return this.each(function(){
var _1b4=$.data(this,"datagrid");
var opts;
if(_1b4){
opts=$.extend(_1b4.options,_1b2);
_1b4.options=opts;
}else{
opts=$.extend({},$.extend({},$.fn.datagrid.defaults,{queryParams:{}}),$.fn.datagrid.parseOptions(this),_1b2);
$(this).css("width","").css("height","");
var _1b5=_4d(this,opts.rownumbers);
if(!opts.columns){
opts.columns=_1b5.columns;
}
if(!opts.frozenColumns){
opts.frozenColumns=_1b5.frozenColumns;
}
opts.columns=$.extend(true,[],opts.columns);
opts.frozenColumns=$.extend(true,[],opts.frozenColumns);
opts.view=$.extend({},opts.view);
$.data(this,"datagrid",{options:opts,panel:_1b5.panel,dc:_1b5.dc,ss:null,selectedRows:[],checkedRows:[],data:{total:0,rows:[]},originalRows:[],updatedRows:[],insertedRows:[],deletedRows:[]});
}
_58(this);
_75(this);
_1a(this);
if(opts.data){
$(this).datagrid("loadData",opts.data);
}else{
var data=$.fn.datagrid.parseData(this);
if(data.total>0){
$(this).datagrid("loadData",data);
}else{
$(this).datagrid("autoSizeColumn");
}
}
_bf(this);
});
};
function _1b6(_1b7){
var _1b8={};
$.map(_1b7,function(name){
_1b8[name]=_1b9(name);
});
return _1b8;
function _1b9(name){
function isA(_1ba){
return $.data($(_1ba)[0],name)!=undefined;
};
return {init:function(_1bb,_1bc){
var _1bd=$("<input type=\"text\" class=\"datagrid-editable-input\">").appendTo(_1bb);
if(_1bd[name]&&name!="text"){
return _1bd[name](_1bc);
}else{
return _1bd;
}
},destroy:function(_1be){
if(isA(_1be,name)){
$(_1be)[name]("destroy");
}
},getValue:function(_1bf){
if(isA(_1bf,name)){
var opts=$(_1bf)[name]("options");
if(opts.multiple){
return $(_1bf)[name]("getValues").join(opts.separator);
}else{
return $(_1bf)[name]("getValue");
}
}else{
return $(_1bf).val();
}
},setValue:function(_1c0,_1c1){
if(isA(_1c0,name)){
var opts=$(_1c0)[name]("options");
if(opts.multiple){
if(_1c1){
$(_1c0)[name]("setValues",_1c1.split(opts.separator));
}else{
$(_1c0)[name]("clear");
}
}else{
$(_1c0)[name]("setValue",_1c1);
}
}else{
$(_1c0).val(_1c1);
}
},resize:function(_1c2,_1c3){
if(isA(_1c2,name)){
$(_1c2)[name]("resize",_1c3);
}else{
$(_1c2)._size({width:_1c3,height:$.fn.datagrid.defaults.editorHeight});
}
}};
};
};
var _1c4=$.extend({},_1b6(["text","textbox","passwordbox","filebox","numberbox","numberspinner","combobox","combotree","combogrid","combotreegrid","datebox","datetimebox","timespinner","datetimespinner"]),{textarea:{init:function(_1c5,_1c6){
var _1c7=$("<textarea class=\"datagrid-editable-input\"></textarea>").appendTo(_1c5);
_1c7.css("vertical-align","middle")._outerHeight(_1c6.height);
return _1c7;
},getValue:function(_1c8){
return $(_1c8).val();
},setValue:function(_1c9,_1ca){
$(_1c9).val(_1ca);
},resize:function(_1cb,_1cc){
$(_1cb)._outerWidth(_1cc);
}},checkbox:{init:function(_1cd,_1ce){
var _1cf=$("<input type=\"checkbox\">").appendTo(_1cd);
_1cf.val(_1ce.on);
_1cf.attr("offval",_1ce.off);
return _1cf;
},getValue:function(_1d0){
if($(_1d0).is(":checked")){
return $(_1d0).val();
}else{
return $(_1d0).attr("offval");
}
},setValue:function(_1d1,_1d2){
var _1d3=false;
if($(_1d1).val()==_1d2){
_1d3=true;
}
$(_1d1)._propAttr("checked",_1d3);
}},validatebox:{init:function(_1d4,_1d5){
var _1d6=$("<input type=\"text\" class=\"datagrid-editable-input\">").appendTo(_1d4);
_1d6.validatebox(_1d5);
return _1d6;
},destroy:function(_1d7){
$(_1d7).validatebox("destroy");
},getValue:function(_1d8){
return $(_1d8).val();
},setValue:function(_1d9,_1da){
$(_1d9).val(_1da);
},resize:function(_1db,_1dc){
$(_1db)._outerWidth(_1dc)._outerHeight($.fn.datagrid.defaults.editorHeight);
}}});
$.fn.datagrid.methods={options:function(jq){
var _1dd=$.data(jq[0],"datagrid").options;
var _1de=$.data(jq[0],"datagrid").panel.panel("options");
var opts=$.extend(_1dd,{width:_1de.width,height:_1de.height,closed:_1de.closed,collapsed:_1de.collapsed,minimized:_1de.minimized,maximized:_1de.maximized});
return opts;
},setSelectionState:function(jq){
return jq.each(function(){
_114(this);
});
},createStyleSheet:function(jq){
return _7(jq[0]);
},getPanel:function(jq){
return $.data(jq[0],"datagrid").panel;
},getPager:function(jq){
return $.data(jq[0],"datagrid").panel.children("div.datagrid-pager");
},getColumnFields:function(jq,_1df){
return _73(jq[0],_1df);
},getColumnOption:function(jq,_1e0){
return _74(jq[0],_1e0);
},resize:function(jq,_1e1){
return jq.each(function(){
_1a(this,_1e1);
});
},load:function(jq,_1e2){
return jq.each(function(){
var opts=$(this).datagrid("options");
if(typeof _1e2=="string"){
opts.url=_1e2;
_1e2=null;
}
opts.pageNumber=1;
var _1e3=$(this).datagrid("getPager");
_1e3.pagination("refresh",{pageNumber:1});
_bf(this,_1e2);
});
},reload:function(jq,_1e4){
return jq.each(function(){
var opts=$(this).datagrid("options");
if(typeof _1e4=="string"){
opts.url=_1e4;
_1e4=null;
}
_bf(this,_1e4);
});
},reloadFooter:function(jq,_1e5){
return jq.each(function(){
var opts=$.data(this,"datagrid").options;
var dc=$.data(this,"datagrid").dc;
if(_1e5){
$.data(this,"datagrid").footer=_1e5;
}
if(opts.showFooter){
opts.view.renderFooter.call(opts.view,this,dc.footer2,false);
opts.view.renderFooter.call(opts.view,this,dc.footer1,true);
if(opts.view.onAfterRender){
opts.view.onAfterRender.call(opts.view,this);
}
$(this).datagrid("fixRowHeight");
}
});
},loading:function(jq){
return jq.each(function(){
var opts=$.data(this,"datagrid").options;
$(this).datagrid("getPager").pagination("loading");
if(opts.loadMsg){
var _1e6=$(this).datagrid("getPanel");
if(!_1e6.children("div.datagrid-mask").length){
$("<div class=\"datagrid-mask\" style=\"display:block\"></div>").appendTo(_1e6);
var msg=$("<div class=\"datagrid-mask-msg\" style=\"display:block;left:50%\"></div>").html(opts.loadMsg).appendTo(_1e6);
msg._outerHeight(40);
msg.css({marginLeft:(-msg.outerWidth()/2),lineHeight:(msg.height()+"px")});
}
}
});
},loaded:function(jq){
return jq.each(function(){
$(this).datagrid("getPager").pagination("loaded");
var _1e7=$(this).datagrid("getPanel");
_1e7.children("div.datagrid-mask-msg").remove();
_1e7.children("div.datagrid-mask").remove();
});
},fitColumns:function(jq){
return jq.each(function(){
_cc(this);
});
},fixColumnSize:function(jq,_1e8){
return jq.each(function(){
_ef(this,_1e8);
});
},fixRowHeight:function(jq,_1e9){
return jq.each(function(){
_34(this,_1e9);
});
},freezeRow:function(jq,_1ea){
return jq.each(function(){
_45(this,_1ea);
});
},autoSizeColumn:function(jq,_1eb){
return jq.each(function(){
_e0(this,_1eb);
});
},loadData:function(jq,data){
return jq.each(function(){
_c0(this,data);
_195(this);
});
},getData:function(jq){
return $.data(jq[0],"datagrid").data;
},getRows:function(jq){
return $.data(jq[0],"datagrid").data.rows;
},getFooterRows:function(jq){
return $.data(jq[0],"datagrid").footer;
},getRowIndex:function(jq,id){
return _11c(jq[0],id);
},getChecked:function(jq){
return _122(jq[0]);
},getSelected:function(jq){
var rows=_11f(jq[0]);
return rows.length>0?rows[0]:null;
},getSelections:function(jq){
return _11f(jq[0]);
},clearSelections:function(jq){
return jq.each(function(){
var _1ec=$.data(this,"datagrid");
var _1ed=_1ec.selectedRows;
var _1ee=_1ec.checkedRows;
_1ed.splice(0,_1ed.length);
_135(this);
if(_1ec.options.checkOnSelect){
_1ee.splice(0,_1ee.length);
}
});
},clearChecked:function(jq){
return jq.each(function(){
var _1ef=$.data(this,"datagrid");
var _1f0=_1ef.selectedRows;
var _1f1=_1ef.checkedRows;
_1f1.splice(0,_1f1.length);
_8a(this);
if(_1ef.options.selectOnCheck){
_1f0.splice(0,_1f0.length);
}
});
},scrollTo:function(jq,_1f2){
return jq.each(function(){
_125(this,_1f2);
});
},highlightRow:function(jq,_1f3){
return jq.each(function(){
_9c(this,_1f3);
_125(this,_1f3);
});
},selectAll:function(jq){
return jq.each(function(){
_13a(this);
});
},unselectAll:function(jq){
return jq.each(function(){
_135(this);
});
},selectRow:function(jq,_1f4){
return jq.each(function(){
_a5(this,_1f4);
});
},selectRecord:function(jq,id){
return jq.each(function(){
var opts=$.data(this,"datagrid").options;
if(opts.idField){
var _1f5=_11c(this,id);
if(_1f5>=0){
$(this).datagrid("selectRow",_1f5);
}
}
});
},unselectRow:function(jq,_1f6){
return jq.each(function(){
_a6(this,_1f6);
});
},checkRow:function(jq,_1f7){
return jq.each(function(){
_a2(this,_1f7);
});
},uncheckRow:function(jq,_1f8){
return jq.each(function(){
_a3(this,_1f8);
});
},checkAll:function(jq){
return jq.each(function(){
_89(this);
});
},uncheckAll:function(jq){
return jq.each(function(){
_8a(this);
});
},beginEdit:function(jq,_1f9){
return jq.each(function(){
_154(this,_1f9);
});
},endEdit:function(jq,_1fa){
return jq.each(function(){
_15a(this,_1fa,false);
});
},cancelEdit:function(jq,_1fb){
return jq.each(function(){
_15a(this,_1fb,true);
});
},getEditors:function(jq,_1fc){
return _167(jq[0],_1fc);
},getEditor:function(jq,_1fd){
return _16b(jq[0],_1fd);
},refreshRow:function(jq,_1fe){
return jq.each(function(){
var opts=$.data(this,"datagrid").options;
opts.view.refreshRow.call(opts.view,this,_1fe);
});
},validateRow:function(jq,_1ff){
return _159(jq[0],_1ff);
},updateRow:function(jq,_200){
return jq.each(function(){
_18f(this,_200);
});
},appendRow:function(jq,row){
return jq.each(function(){
_18c(this,row);
});
},insertRow:function(jq,_201){
return jq.each(function(){
_188(this,_201);
});
},deleteRow:function(jq,_202){
return jq.each(function(){
_182(this,_202);
});
},getChanges:function(jq,_203){
return _17c(jq[0],_203);
},acceptChanges:function(jq){
return jq.each(function(){
_199(this);
});
},rejectChanges:function(jq){
return jq.each(function(){
_19b(this);
});
},mergeCells:function(jq,_204){
return jq.each(function(){
_1ad(this,_204);
});
},showColumn:function(jq,_205){
return jq.each(function(){
var col=$(this).datagrid("getColumnOption",_205);
if(col.hidden){
col.hidden=false;
$(this).datagrid("getPanel").find("td[field=\""+_205+"\"]").show();
_c1(this,_205,1);
$(this).datagrid("fitColumns");
}
});
},hideColumn:function(jq,_206){
return jq.each(function(){
var col=$(this).datagrid("getColumnOption",_206);
if(!col.hidden){
col.hidden=true;
$(this).datagrid("getPanel").find("td[field=\""+_206+"\"]").hide();
_c1(this,_206,-1);
$(this).datagrid("fitColumns");
}
});
},sort:function(jq,_207){
return jq.each(function(){
_8c(this,_207);
});
},gotoPage:function(jq,_208){
return jq.each(function(){
var _209=this;
var page,cb;
if(typeof _208=="object"){
page=_208.page;
cb=_208.callback;
}else{
page=_208;
}
$(_209).datagrid("options").pageNumber=page;
$(_209).datagrid("getPager").pagination("refresh",{pageNumber:page});
_bf(_209,null,function(){
if(cb){
cb.call(_209,page);
}
});
});
}};
$.fn.datagrid.parseOptions=function(_20a){
var t=$(_20a);
return $.extend({},$.fn.panel.parseOptions(_20a),$.parser.parseOptions(_20a,["url","toolbar","idField","sortName","sortOrder","pagePosition","resizeHandle",{sharedStyleSheet:"boolean",fitColumns:"boolean",autoRowHeight:"boolean",striped:"boolean",nowrap:"boolean"},{rownumbers:"boolean",singleSelect:"boolean",ctrlSelect:"boolean",checkOnSelect:"boolean",selectOnCheck:"boolean"},{pagination:"boolean",pageSize:"number",pageNumber:"number"},{multiSort:"boolean",remoteSort:"boolean",showHeader:"boolean",showFooter:"boolean"},{scrollbarSize:"number",scrollOnSelect:"boolean"}]),{pageList:(t.attr("pageList")?eval(t.attr("pageList")):undefined),loadMsg:(t.attr("loadMsg")!=undefined?t.attr("loadMsg"):undefined),rowStyler:(t.attr("rowStyler")?eval(t.attr("rowStyler")):undefined)});
};
$.fn.datagrid.parseData=function(_20b){
var t=$(_20b);
var data={total:0,rows:[]};
var _20c=t.datagrid("getColumnFields",true).concat(t.datagrid("getColumnFields",false));
t.find("tbody tr").each(function(){
data.total++;
var row={};
$.extend(row,$.parser.parseOptions(this,["iconCls","state"]));
for(var i=0;i<_20c.length;i++){
row[_20c[i]]=$(this).find("td:eq("+i+")").html();
}
data.rows.push(row);
});
return data;
};
var _20d={render:function(_20e,_20f,_210){
var rows=$(_20e).datagrid("getRows");
$(_20f).empty().html(this.renderTable(_20e,0,rows,_210));
},renderFooter:function(_211,_212,_213){
var opts=$.data(_211,"datagrid").options;
var rows=$.data(_211,"datagrid").footer||[];
var _214=$(_211).datagrid("getColumnFields",_213);
var _215=["<table class=\"datagrid-ftable\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\"><tbody>"];
for(var i=0;i<rows.length;i++){
_215.push("<tr class=\"datagrid-row\" datagrid-row-index=\""+i+"\">");
_215.push(this.renderRow.call(this,_211,_214,_213,i,rows[i]));
_215.push("</tr>");
}
_215.push("</tbody></table>");
$(_212).html(_215.join(""));
},renderTable:function(_216,_217,rows,_218){
var _219=$.data(_216,"datagrid");
var opts=_219.options;
if(_218){
if(!(opts.rownumbers||(opts.frozenColumns&&opts.frozenColumns.length))){
return "";
}
}
var _21a=$(_216).datagrid("getColumnFields",_218);
var _21b=["<table class=\"datagrid-btable\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\"><tbody>"];
for(var i=0;i<rows.length;i++){
var row=rows[i];
var css=opts.rowStyler?opts.rowStyler.call(_216,_217,row):"";
var cs=this.getStyleValue(css);
var cls="class=\"datagrid-row "+(_217%2&&opts.striped?"datagrid-row-alt ":" ")+cs.c+"\"";
var _21c=cs.s?"style=\""+cs.s+"\"":"";
var _21d=_219.rowIdPrefix+"-"+(_218?1:2)+"-"+_217;
_21b.push("<tr id=\""+_21d+"\" datagrid-row-index=\""+_217+"\" "+cls+" "+_21c+">");
_21b.push(this.renderRow.call(this,_216,_21a,_218,_217,row));
_21b.push("</tr>");
_217++;
}
_21b.push("</tbody></table>");
return _21b.join("");
},renderRow:function(_21e,_21f,_220,_221,_222){
var opts=$.data(_21e,"datagrid").options;
var cc=[];
if(_220&&opts.rownumbers){
var _223=_221+1;
if(opts.pagination){
_223+=(opts.pageNumber-1)*opts.pageSize;
}
cc.push("<td class=\"datagrid-td-rownumber\"><div class=\"datagrid-cell-rownumber\">"+_223+"</div></td>");
}
for(var i=0;i<_21f.length;i++){
var _224=_21f[i];
var col=$(_21e).datagrid("getColumnOption",_224);
if(col){
var _225=_222[_224];
var css=col.styler?(col.styler.call(_21e,_225,_222,_221)||""):"";
var cs=this.getStyleValue(css);
var cls=cs.c?"class=\""+cs.c+"\"":"";
var _226=col.hidden?"style=\"display:none;"+cs.s+"\"":(cs.s?"style=\""+cs.s+"\"":"");
cc.push("<td field=\""+_224+"\" "+cls+" "+_226+">");
var _226="";
if(!col.checkbox){
if(col.align){
_226+="text-align:"+col.align+";";
}
if(!opts.nowrap){
_226+="white-space:normal;height:auto;";
}else{
if(opts.autoRowHeight){
_226+="height:auto;";
}
}
}
cc.push("<div style=\""+_226+"\" ");
cc.push(col.checkbox?"class=\"datagrid-cell-check\"":"class=\"datagrid-cell "+col.cellClass+"\"");
cc.push(">");
if(col.checkbox){
cc.push("<input type=\"checkbox\" "+(_222.checked?"checked=\"checked\"":""));
cc.push(" name=\""+_224+"\" value=\""+(_225!=undefined?_225:"")+"\">");
}else{
if(col.formatter){
cc.push(col.formatter(_225,_222,_221));
}else{
cc.push(_225);
}
}
cc.push("</div>");
cc.push("</td>");
}
}
return cc.join("");
},getStyleValue:function(css){
var _227="";
var _228="";
if(typeof css=="string"){
_228=css;
}else{
if(css){
_227=css["class"]||"";
_228=css["style"]||"";
}
}
return {c:_227,s:_228};
},refreshRow:function(_229,_22a){
this.updateRow.call(this,_229,_22a,{});
},updateRow:function(_22b,_22c,row){
var opts=$.data(_22b,"datagrid").options;
var _22d=opts.finder.getRow(_22b,_22c);
$.extend(_22d,row);
var cs=_22e.call(this,_22c);
var _22f=cs.s;
var cls="datagrid-row "+(_22c%2&&opts.striped?"datagrid-row-alt ":" ")+cs.c;
function _22e(_230){
var css=opts.rowStyler?opts.rowStyler.call(_22b,_230,_22d):"";
return this.getStyleValue(css);
};
function _231(_232){
var tr=opts.finder.getTr(_22b,_22c,"body",(_232?1:2));
if(!tr.length){
return;
}
var _233=$(_22b).datagrid("getColumnFields",_232);
var _234=tr.find("div.datagrid-cell-check input[type=checkbox]").is(":checked");
tr.html(this.renderRow.call(this,_22b,_233,_232,_22c,_22d));
var _235=(tr.hasClass("datagrid-row-checked")?" datagrid-row-checked":"")+(tr.hasClass("datagrid-row-selected")?" datagrid-row-selected":"");
tr.attr("style",_22f).attr("class",cls+_235);
if(_234){
tr.find("div.datagrid-cell-check input[type=checkbox]")._propAttr("checked",true);
}
};
_231.call(this,true);
_231.call(this,false);
$(_22b).datagrid("fixRowHeight",_22c);
},insertRow:function(_236,_237,row){
var _238=$.data(_236,"datagrid");
var opts=_238.options;
var dc=_238.dc;
var data=_238.data;
if(_237==undefined||_237==null){
_237=data.rows.length;
}
if(_237>data.rows.length){
_237=data.rows.length;
}
function _239(_23a){
var _23b=_23a?1:2;
for(var i=data.rows.length-1;i>=_237;i--){
var tr=opts.finder.getTr(_236,i,"body",_23b);
tr.attr("datagrid-row-index",i+1);
tr.attr("id",_238.rowIdPrefix+"-"+_23b+"-"+(i+1));
if(_23a&&opts.rownumbers){
var _23c=i+2;
if(opts.pagination){
_23c+=(opts.pageNumber-1)*opts.pageSize;
}
tr.find("div.datagrid-cell-rownumber").html(_23c);
}
if(opts.striped){
tr.removeClass("datagrid-row-alt").addClass((i+1)%2?"datagrid-row-alt":"");
}
}
};
function _23d(_23e){
var _23f=_23e?1:2;
var _240=$(_236).datagrid("getColumnFields",_23e);
var _241=_238.rowIdPrefix+"-"+_23f+"-"+_237;
var tr="<tr id=\""+_241+"\" class=\"datagrid-row\" datagrid-row-index=\""+_237+"\"></tr>";
if(_237>=data.rows.length){
if(data.rows.length){
opts.finder.getTr(_236,"","last",_23f).after(tr);
}else{
var cc=_23e?dc.body1:dc.body2;
cc.html("<table class=\"datagrid-btable\" cellspacing=\"0\" cellpadding=\"0\" border=\"0\"><tbody>"+tr+"</tbody></table>");
}
}else{
opts.finder.getTr(_236,_237+1,"body",_23f).before(tr);
}
};
_239.call(this,true);
_239.call(this,false);
_23d.call(this,true);
_23d.call(this,false);
data.total+=1;
data.rows.splice(_237,0,row);
this.setEmptyMsg(_236);
this.refreshRow.call(this,_236,_237);
},deleteRow:function(_242,_243){
var _244=$.data(_242,"datagrid");
var opts=_244.options;
var data=_244.data;
function _245(_246){
var _247=_246?1:2;
for(var i=_243+1;i<data.rows.length;i++){
var tr=opts.finder.getTr(_242,i,"body",_247);
tr.attr("datagrid-row-index",i-1);
tr.attr("id",_244.rowIdPrefix+"-"+_247+"-"+(i-1));
if(_246&&opts.rownumbers){
var _248=i;
if(opts.pagination){
_248+=(opts.pageNumber-1)*opts.pageSize;
}
tr.find("div.datagrid-cell-rownumber").html(_248);
}
if(opts.striped){
tr.removeClass("datagrid-row-alt").addClass((i-1)%2?"datagrid-row-alt":"");
}
}
};
opts.finder.getTr(_242,_243).remove();
_245.call(this,true);
_245.call(this,false);
data.total-=1;
data.rows.splice(_243,1);
this.setEmptyMsg(_242);
},onBeforeRender:function(_249,rows){
},onAfterRender:function(_24a){
var _24b=$.data(_24a,"datagrid");
var opts=_24b.options;
if(opts.showFooter){
var _24c=$(_24a).datagrid("getPanel").find("div.datagrid-footer");
_24c.find("div.datagrid-cell-rownumber,div.datagrid-cell-check").css("visibility","hidden");
}
this.setEmptyMsg(_24a);
},setEmptyMsg:function(_24d){
var _24e=$.data(_24d,"datagrid");
var opts=_24e.options;
var _24f=opts.finder.getRows(_24d).length==0;
if(_24f){
this.renderEmptyRow(_24d);
}
if(opts.emptyMsg){
_24e.dc.view.children(".datagrid-empty").remove();
if(_24f){
var h=_24e.dc.header2.parent().outerHeight();
var d=$("<div class=\"datagrid-empty\"></div>").appendTo(_24e.dc.view);
d.html(opts.emptyMsg).css("top",h+"px");
}
}
},renderEmptyRow:function(_250){
var cols=$.map($(_250).datagrid("getColumnFields"),function(_251){
return $(_250).datagrid("getColumnOption",_251);
});
$.map(cols,function(col){
col.formatter1=col.formatter;
col.styler1=col.styler;
col.formatter=col.styler=undefined;
});
var _252=$.data(_250,"datagrid").dc.body2;
_252.html(this.renderTable(_250,0,[{}],false));
_252.find("tbody *").css({height:1,borderColor:"transparent",background:"transparent"});
var tr=_252.find(".datagrid-row");
tr.removeClass("datagrid-row").removeAttr("datagrid-row-index");
tr.find(".datagrid-cell,.datagrid-cell-check").empty();
$.map(cols,function(col){
col.formatter=col.formatter1;
col.styler=col.styler1;
col.formatter1=col.styler1=undefined;
});
}};
$.fn.datagrid.defaults=$.extend({},$.fn.panel.defaults,{sharedStyleSheet:false,frozenColumns:undefined,columns:undefined,fitColumns:false,resizeHandle:"right",resizeEdge:5,autoRowHeight:true,toolbar:null,striped:false,method:"post",nowrap:true,idField:null,url:null,data:null,loadMsg:"Processing, please wait ...",emptyMsg:"",rownumbers:false,singleSelect:false,ctrlSelect:false,selectOnCheck:true,checkOnSelect:true,pagination:false,pagePosition:"bottom",pageNumber:1,pageSize:10,pageList:[10,20,30,40,50],queryParams:{},sortName:null,sortOrder:"asc",multiSort:false,remoteSort:true,showHeader:true,showFooter:false,scrollOnSelect:true,scrollbarSize:18,rownumberWidth:30,editorHeight:24,headerEvents:{mouseover:_82(true),mouseout:_82(false),click:_86,dblclick:_8d,contextmenu:_93},rowEvents:{mouseover:_96(true),mouseout:_96(false),click:_9e,dblclick:_a9,contextmenu:_ae},rowStyler:function(_253,_254){
},loader:function(_255,_256,_257){
var opts=$(this).datagrid("options");
if(!opts.url){
return false;
}
$.ajax({type:opts.method,url:opts.url,data:_255,dataType:"json",success:function(data){
_256(data);
},error:function(){
_257.apply(this,arguments);
}});
},loadFilter:function(data){
return data;
},editors:_1c4,finder:{getTr:function(_258,_259,type,_25a){
type=type||"body";
_25a=_25a||0;
var _25b=$.data(_258,"datagrid");
var dc=_25b.dc;
var opts=_25b.options;
if(_25a==0){
var tr1=opts.finder.getTr(_258,_259,type,1);
var tr2=opts.finder.getTr(_258,_259,type,2);
return tr1.add(tr2);
}else{
if(type=="body"){
var tr=$("#"+_25b.rowIdPrefix+"-"+_25a+"-"+_259);
if(!tr.length){
tr=(_25a==1?dc.body1:dc.body2).find(">table>tbody>tr[datagrid-row-index="+_259+"]");
}
return tr;
}else{
if(type=="footer"){
return (_25a==1?dc.footer1:dc.footer2).find(">table>tbody>tr[datagrid-row-index="+_259+"]");
}else{
if(type=="selected"){
return (_25a==1?dc.body1:dc.body2).find(">table>tbody>tr.datagrid-row-selected");
}else{
if(type=="highlight"){
return (_25a==1?dc.body1:dc.body2).find(">table>tbody>tr.datagrid-row-over");
}else{
if(type=="checked"){
return (_25a==1?dc.body1:dc.body2).find(">table>tbody>tr.datagrid-row-checked");
}else{
if(type=="editing"){
return (_25a==1?dc.body1:dc.body2).find(">table>tbody>tr.datagrid-row-editing");
}else{
if(type=="last"){
return (_25a==1?dc.body1:dc.body2).find(">table>tbody>tr[datagrid-row-index]:last");
}else{
if(type=="allbody"){
return (_25a==1?dc.body1:dc.body2).find(">table>tbody>tr[datagrid-row-index]");
}else{
if(type=="allfooter"){
return (_25a==1?dc.footer1:dc.footer2).find(">table>tbody>tr[datagrid-row-index]");
}
}
}
}
}
}
}
}
}
}
},getRow:function(_25c,p){
var _25d=(typeof p=="object")?p.attr("datagrid-row-index"):p;
return $.data(_25c,"datagrid").data.rows[parseInt(_25d)];
},getRows:function(_25e){
return $(_25e).datagrid("getRows");
}},view:_20d,onBeforeLoad:function(_25f){
},onLoadSuccess:function(){
},onLoadError:function(){
},onClickRow:function(_260,_261){
},onDblClickRow:function(_262,_263){
},onClickCell:function(_264,_265,_266){
},onDblClickCell:function(_267,_268,_269){
},onBeforeSortColumn:function(sort,_26a){
},onSortColumn:function(sort,_26b){
},onResizeColumn:function(_26c,_26d){
},onBeforeSelect:function(_26e,_26f){
},onSelect:function(_270,_271){
},onBeforeUnselect:function(_272,_273){
},onUnselect:function(_274,_275){
},onSelectAll:function(rows){
},onUnselectAll:function(rows){
},onBeforeCheck:function(_276,_277){
},onCheck:function(_278,_279){
},onBeforeUncheck:function(_27a,_27b){
},onUncheck:function(_27c,_27d){
},onCheckAll:function(rows){
},onUncheckAll:function(rows){
},onBeforeEdit:function(_27e,_27f){
},onBeginEdit:function(_280,_281){
},onEndEdit:function(_282,_283,_284){
},onAfterEdit:function(_285,_286,_287){
},onCancelEdit:function(_288,_289){
},onHeaderContextMenu:function(e,_28a){
},onRowContextMenu:function(e,_28b,_28c){
}});
})(jQuery);

