.window {
  overflow: hidden;
  padding: 5px;
  border-width: 1px;
  border-style: solid;
}
.window .window-header {
  background: transparent;
  padding: 0px 0px 6px 0px;
}
.window .window-body {
  border-width: 1px;
  border-style: solid;
  border-top-width: 0px;
}
.window .window-body-noheader {
  border-top-width: 1px;
}
.window .panel-body-nobottom {
  border-bottom-width: 0;
}
.window .window-header .panel-icon,
.window .window-header .panel-tool {
  top: 50%;
  margin-top: -11px;
}
.window .window-header .panel-icon {
  left: 1px;
}
.window .window-header .panel-tool {
  right: 1px;
}
.window .window-header .panel-with-icon {
  padding-left: 18px;
}
.window-proxy {
  position: absolute;
  overflow: hidden;
}
.window-proxy-mask {
  position: absolute;
  filter: alpha(opacity=5);
  opacity: 0.05;
}
.window-mask {
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  filter: alpha(opacity=40);
  opacity: 0.40;
  font-size: 1px;
  overflow: hidden;
}
.window,
.window-shadow {
  position: absolute;
  -moz-border-radius: 5px 5px 5px 5px;
  -webkit-border-radius: 5px 5px 5px 5px;
  border-radius: 5px 5px 5px 5px;
}
.window-shadow {
  background: #ccc;
  -moz-box-shadow: 2px 2px 3px #cccccc;
  -webkit-box-shadow: 2px 2px 3px #cccccc;
  box-shadow: 2px 2px 3px #cccccc;
  filter: progid:DXImageTransform.Microsoft.Blur(pixelRadius=2,MakeShadow=false,ShadowOpacity=0.2);
}
.window,
.window .window-body {
  border-color: #D3D3D3;
}
.window {
  background-color: #f3f3f3;
  background: -webkit-linear-gradient(top,#F8F8F8 0,#eeeeee 20%);
  background: -moz-linear-gradient(top,#F8F8F8 0,#eeeeee 20%);
  background: -o-linear-gradient(top,#F8F8F8 0,#eeeeee 20%);
  background: linear-gradient(to bottom,#F8F8F8 0,#eeeeee 20%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr=#F8F8F8,endColorstr=#eeeeee,GradientType=0);
}
.window-proxy {
  border: 1px dashed #D3D3D3;
}
.window-proxy-mask,
.window-mask {
  background: #ccc;
}
.window .panel-footer {
  border: 1px solid #D3D3D3;
  position: relative;
  top: -1px;
}
.window-thinborder {
  padding: 0;
}
.window-thinborder .window-header {
  padding: 5px 5px 6px 5px;
}
.window-thinborder .window-body {
  border-width: 0px;
}
.window-thinborder .window-header .panel-icon,
.window-thinborder .window-header .panel-tool {
  margin-top: -9px;
  margin-left: 5px;
  margin-right: 5px;
}
.window-noborder {
  border: 0;
}
