.dialog-content {
  overflow: auto;
}
.dialog-toolbar {
  position: relative;
  padding: 2px 5px;
}
.dialog-tool-separator {
  float: left;
  height: 24px;
  border-left: 1px solid #ccc;
  border-right: 1px solid #fff;
  margin: 2px 1px;
}
.dialog-button {
  position: relative;
  top: -1px;
  padding: 5px;
  text-align: right;
}
.dialog-button .l-btn {
  margin-left: 5px;
}
.dialog-toolbar,
.dialog-button {
  background: #F4F4F4;
  border-width: 1px;
  border-style: solid;
}
.dialog-toolbar {
  border-color: #95B8E7 #95B8E7 #dddddd #95B8E7;
}
.dialog-button {
  border-color: #dddddd #95B8E7 #95B8E7 #95B8E7;
}
.window-thinborder .dialog-toolbar {
  border-left: transparent;
  border-right: transparent;
  border-top-color: #F4F4F4;
}
.window-thinborder .dialog-button {
  top: 0px;
  padding: 5px 8px 8px 8px;
  border-left: transparent;
  border-right: transparent;
  border-bottom: transparent;
}
