{% load i18n %}

<div class="well well-sm search-form-wrapper" style="visibility: hidden;">
    <form method="GET" class="form-inline">
        {% for field in search_form %}
            {% include 'dartcms/forms/partial/inline_field.html' %}
        {% endfor %}
        <a href="{{ request.path }}" class="btn btn-default">{% trans 'Clear' %}</a>&nbsp;
        <input type="submit" name="search" class="btn btn-primary" value="{% trans 'Search' %}"/>
    </form>
</div>
