# Generated by Django 1.9.8 on 2016-08-01 16:07
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('feedback', '0002_auto_20160713_0349'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='formtype',
            options={'verbose_name': 'Form type', 'verbose_name_plural': 'Form types'},
        ),
    ]
