{% extends "dartcms/base/index.html" %}

{% load static i18n %}

{% block wrapper %}
    <div class="form-window">
        <div class="panel panel-default panel-login">
            <div class="panel-heading">
                <h3 class="panel-title">
                    <img src="{% static 'dartcms/images/logo.png' %}"/>
                </h3>
            </div>
            <div class="panel-body">
                <form method="POST" id="id-login-form">
                    {% csrf_token %}
                    {{ form.next }}
                    {{ form.non_field_errors }}
                    <div class="form-group">
                        <div class="input-group">
                            <span class="input-group-addon">
                                <i class="fa fa-user"></i>
                            </span>
                            <input autofocus="autofocus" type="text" class="form-control"
                                   placeholder="{{ form.username.label }}" name="username">
                        </div>
                    </div>
                    <div class="form-group">
                        <div class="input-group">
                            <span class="input-group-addon">
                                <i class="fa fa-lock"></i>
                            </span>
                            <input type="password" class="form-control" placeholder="{% trans 'Password' %}"
                                   name="password">
                        </div>
                    </div>
                    <div class="form-actions">
                        <div class="pull-right">
                            <button type="submit" class="btn btn-primary">
                                <i class="fa fa-sign-in"></i> {% trans 'Login' %}
                            </button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
{% endblock %}